
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class RefundOrderModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(RefundOrderModel, self).__init__(RefundOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class RefundOrder:

    def __init__(self):
        super(RefundOrder, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.user_nick = ""  # 买家昵称
        self.refund_id = ""  # 退款单号
        self.main_order_no = ""  # 淘宝主订单号
        self.seller_nick = ""  # 卖家昵称
        self.refund_created = "1900-01-01 00:00:00"  # 退款申请时间
        self.refund_fee = 0  # 退款总金额
        self.refund_num = 0  # 退款数量
        self.pay_order_id = 0  # 支付订单表对应id
        self.lottery_value_log_id = 0  # 积分明细表对应获得id
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'user_nick', 'refund_id', 'main_order_no', 'seller_nick', 'refund_created', 'refund_fee', 'refund_num', 'pay_order_id', 'lottery_value_log_id', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "refund_order_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-06-02 14:32:40
:LastEditTime: 2021-03-10 18:23:27
:LastEditors: HuangJingCan
:description: 枚举类
"""

from enum import Enum, unique


class TagType(Enum):
    """
    :description: 标签类型
    """
    无 = 0
    限定 = 1
    稀有 = 2
    绝版 = 3
    隐藏 = 4


class SourceType(Enum):
    """
    :description: 用户次数配置来源类型
    """
    购买 = 1
    任务 = 2
    手动配置 = 3


class OperationType(Enum):
    """
    :description: 用户操作日志类型
    """
    add = 1
    update = 2
    delete = 3


class TaskType(Enum):
    """
    docstring：任务类型
    """
    # 新人有礼，格式：{"reward_value":0}
    free = 1
    # 每日签到，格式：{"reward_value":0}
    sign = 2
    # 邀请新用户，格式：{"reward_value":0,"user_limit":0}
    invite = 3
    # 关注店铺，格式：{"reward_value":0}
    favor = 4
    # 加入店铺会员，格式：{"reward_value":0}
    member = 5
    # 下单购买指定商品，格式：{"reward_value":0,"num_limit":0,"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00',"goods_ids":"","goods_list":[]}
    buy = 6
    # 收藏商品，格式：{"reward_value":0,"num_limit":0,"goods_ids":"","goods_list":[]}
    collect = 7
    # 浏览商品，格式：{"reward_value":0,"num_limit":0,"goods_ids":"","goods_list":[]}
    browse = 8
    # 加入群聊，格式：{"reward_value":0,"join_type":（1商家群链接2选择单群聊）,"join_url":"","chatting_id":"","chatting_name":""}
    join_chatting = 9
    # 分享群聊，格式：{"reward_value":0,"chatting_id":"","chatting_name":""}
    share_chatting = 10
    # 直播，格式：云应用未开放此功能
    live_telecast = 11
    # 每周签到，格式：{"1": 0, "2": 0, "3": 0, "4": 0, "5": 0, "6": 0, "7": 0}
    weekly_sign = 12
    # 下单任意消费，格式：{"reward_value":0,"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00'}
    arbitrarily_consumption = 13
    # 累计消费，格式：{"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00',"reward_list":[{"key":"前端算唯一值","money":500,"reward_value":0}]}
    totle_consumption = 14
    # 单笔订单消费，格式：{"effective_date_start":'1900-01-01 00:00:00',"effective_date_end":'1900-01-01 00:00:00',"reward_list":[{"key":"前端算唯一值","money":500,"reward_value":0}]}
    one_consumption = 15
    # 店长好礼，格式：从活动奖品表配置
    shopowner_gift = 16
    # 抽奖送积分
    lottery_points = 17




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class EndboxOrderModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(EndboxOrderModel, self).__init__(EndboxOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class EndboxOrder:

    def __init__(self):
        super(EndboxOrder, self).__init__()
        self.id = 0  # id
        self.order_no = ""  # 订单号
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.series_id = 0  # IP系列id
        self.machine_id = 0  # 机台id
        self.machine_name = ""  # 机台名称
        self.specs_type = 0  # 端盒规格
        self.endbox_price = 0  # 端盒价格
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'order_no', 'app_id', 'act_id', 'open_id', 'user_nick', 'series_id', 'machine_id', 'machine_name', 'specs_type', 'endbox_price', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "endbox_order_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-19 11:33:16
:LastEditTime: 2021-06-07 10:38:31
:LastEditors: HuangJingCan
:description: 用户处理
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.behavior_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.user.user_base_model import *
from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.user.user_blacklist_model import *
from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.machine.machine_value_model import *
from seven_cloudapp.models.db_models.gear.gear_value_model import *
from seven_cloudapp.models.db_models.lottery.lottery_value_log_model import *
from seven_cloudapp.models.db_models.user.user_detail_model import *


class LoginHandler(SevenBaseHandler):
    """
    :description: 登录处理
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 登录日志入库
        :param owner_open_id：应用拥有者唯一标识
        :param act_id:活动id
        :param owner_open_id:owner_open_id
        :param is_machine:是否机台
        :param is_gear:是否价格挡位
        :return: dict
        :last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        user_nick = self.get_taobao_param().user_nick
        app_id = self.get_taobao_param().source_app_id
        owner_open_id = self.get_param("owner_open_id")
        act_id = int(self.get_param("act_id", 0))
        # 0-没关联机台或者价格挡位，1-关联机台，2-关联价格挡位
        is_machine_gear = config.get_value("is_machine_gear", 0)

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        if is_machine_gear in (1, 2):
            machine_dict_list = MachineInfoModel(context=self).get_dict_list("act_id=%s", params=[act_id])
            if not machine_dict_list:
                return self.reponse_json_error("NoMachine", "对不起，盲盒不存在")

        # 用户基础表
        user_base = UserBaseModel(context=self).get_entity("open_id=%s", params=[open_id])

        user_info_model = UserInfoModel(context=self)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])

        try:
            if not user_info:
                user_info = UserInfo()
                user_info.open_id = open_id
                user_info.act_id = act_id
                user_info.app_id = app_id
                user_info.is_new = 1
                if user_base:
                    user_info.user_nick = user_base.user_nick
                    user_info.avatar = user_base.avatar
                if user_nick:
                    user_info.user_nick = user_nick
                user_info.create_date = self.get_now_datetime()
                user_info.modify_date = self.get_now_datetime()
                user_info.login_token = SevenHelper.get_random(16, 1)
                user_info.id = user_info_model.add_entity(user_info)
            else:
                if user_base:
                    user_info.user_nick = user_base.user_nick
                    user_info.avatar = user_base.avatar
                if user_nick:
                    user_info.user_nick = user_nick
                user_info.modify_date = self.get_now_datetime()
                user_info.login_token = SevenHelper.get_random(16, 1)
                user_info.is_new = 0
                user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar")
        except Exception as ex:
            self.logging_link_error(traceback.format_exc())

        user_info_dict = user_info.__dict__

        if is_machine_gear == 1:
            machine_value_list = MachineValueModel(context=self).get_dict_list("act_id=%s and open_id=%s", params=[act_id, open_id])
            user_info_dict["machine_value_list"] = machine_value_list
        elif is_machine_gear == 2:
            gear_value_list = GearValueModel(context=self).get_dict_list("act_id=%s and open_id=%s", params=[act_id, open_id])
            user_info_dict["gear_value_list"] = gear_value_list

        behavior_model = BehaviorModel(context=self)
        # 访问次数
        behavior_model.report_behavior_log(app_id, act_id, open_id, owner_open_id, 'VisitCountEveryDay', 1)
        # 访问人数
        behavior_model.report_behavior_log(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDay', 1)
        if user_info.is_new == 1:
            # 新增用户数
            behavior_model.report_behavior_log(app_id, act_id, open_id, owner_open_id, 'VisitManCountEveryDayIncrease', 1)

        return self.reponse_json_success(user_info_dict)


class UserHandler(SevenBaseHandler):
    """
    :description: 更新用户信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 更新用户信息
        :param avatar：头像
        :param act_id：活动id
        :return: 
        :last_editors: HuangJingCan
        """
        try:
            open_id = self.get_taobao_param().open_id
            user_nick = self.get_taobao_param().user_nick
            act_id = int(self.get_param("act_id", 0))
            avatar = self.get_param("avatar")

            user_info_model = UserInfoModel(context=self)
            user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
            if not user_info:
                return self.reponse_json_error("NoUser", "对不起，用户不存在")

            if user_nick:
                user_info.user_nick = user_nick
            user_info.avatar = avatar
            user_info.is_auth = 1
            user_info.modify_date = self.get_now_datetime()
            user_info_model.update_entity(user_info)

            # 用户基础表
            user_base_model = UserBaseModel(context=self)
            user_base = user_base_model.get_entity("open_id=%s", params=[open_id])
            if user_base:
                if user_nick:
                    user_base.user_nick = user_nick
                if avatar:
                    user_base.avatar = avatar
                user_base.modify_date = self.get_now_datetime()
                user_base_model.update_entity(user_base, "modify_date,avatar,user_nick")
            else:
                user_base = UserBase()
                user_base.open_id = open_id
                if user_nick:
                    user_base.user_nick = user_nick
                if avatar:
                    user_base.avatar = avatar
                user_base.is_auth = 1
                user_base.user_state = 0
                user_base.create_date = self.get_now_datetime()
                user_base.modify_date = self.get_now_datetime()
                user_base_model.add_entity(user_base)

            return self.reponse_json_success("更新成功")
        except Exception as ex:
            return self.reponse_json_error("Error", "更新失败")


class SubmitUnbindHandler(SevenBaseHandler):
    """
    :description: 提交黑名单解封申请
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 提交黑名单解封申请
        :param {act_id:活动id}
        :param {reason:解封理由}
        :return {*}
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        act_id = int(self.get_param("act_id", 0))
        reason = self.get_param("reason", "误封号,申请解封")

        user_info_model = UserInfoModel(context=self)
        user_info = user_info_model.get_entity("act_id=%s AND open_id=%s", params=[act_id, open_id])
        if not user_info:
            return self.reponse_json_error("Error", "用户信息不存在")
        if user_info.user_state == 0:
            return self.reponse_json_error("Error", "账号正常,无需申请解封")

        user_blacklist_model = UserBlacklistModel(context=self)
        user_blacklist = user_blacklist_model.get_entity("act_id=%s and open_id=%s", order_by="create_date desc", params=[act_id, open_id])

        if not user_blacklist:
            return self.reponse_json_error("Error", "账号正常,无需申请解封")
        if user_blacklist.audit_status == 1:
            return self.reponse_json_error("Error", "请耐心等待客服处理")

        user_blacklist.audit_status = 1
        user_blacklist_model.update_entity(user_blacklist, "audit_status")

        return self.reponse_json_success()


class GetUnbindApplyHandler(SevenBaseHandler):
    """
    :description: 获取黑名单解封申请记录
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取黑名单解封申请记录
        :param act_id:活动id
        :return 
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        act_id = int(self.get_param("act_id", 0))

        user_info_model = UserInfoModel(context=self)
        user_info = user_info_model.get_entity("act_id=%s AND open_id=%s", params=[act_id, open_id])
        if not user_info:
            return self.reponse_json_error("Error", "用户信息不存在")

        user_blacklist_model = UserBlacklistModel(context=self)
        user_blacklist = user_blacklist_model.get_entity("act_id=%s AND open_id=%s", order_by="create_date desc", params=[act_id, open_id])

        return self.reponse_json_success(user_blacklist)


class GetIntegralListHandler(SevenBaseHandler):
    """
    :description: 获取心愿值记录列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取心愿值记录列表
        :param act_id:活动id
        :param page_index：页索引
        :param page_size：页大小
        :return list
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        lottery_value_log_model = LotteryValueLogModel(context=self)
        condition = "act_id=%s and open_id=%s and currency_type=2"
        params = [act_id, open_id]
        field = "log_title,source_type,current_value,operate_type,create_date"

        lottery_value_log_page_list, total = lottery_value_log_model.get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)
        if len(lottery_value_log_page_list) > 0:
            for item in lottery_value_log_page_list:
                item["create_date"] = item["create_date"].strftime('%Y-%m-%d')
                # item["create_date"] = item["create_date"].strftime('%Y-%m-%d %H:%M:%S')

        page_info = PageInfo(page_index, page_size, total, lottery_value_log_page_list)

        return self.reponse_json_success(page_info)


class GetUserDetailHandler(SevenBaseHandler):
    """
    :description: 获取用户详情（包含道具卡数量）
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取用户详情（包含道具卡数量）
        :param act_id:活动id
        :return
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        act_id = int(self.get_param("act_id", 0))

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        user_detail_model = UserDetailModel(context=self)
        user_detail = user_detail_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        if not user_detail:
            user_detail = UserDetail()
            user_detail.app_id = app_id
            user_detail.act_id = act_id
            user_detail.open_id = open_id
            user_detail.tips_card_count = 0
            user_detail.perspective_card_count = 0
            user_detail.redraw_card_count = 0
            user_detail.create_date = self.get_now_datetime()
            user_detail_model.add_entity(user_detail)

        return self.reponse_json_success(user_detail)



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class MachineInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(MachineInfoModel, self).__init__(MachineInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class MachineInfo:

    def __init__(self):
        super(MachineInfo, self).__init__()
        self.id = 0  # 
        self.act_id = 0  # act_id
        self.app_id = ""  # app_id
        self.machine_name = ""  # 机台名称
        self.machine_type = 0  # 机台类型：1消耗积分2消耗次数
        self.goods_id = ""  # 商品id
        self.goods_modify_date = "1900-01-01 00:00:00"  # 最后修改商品id时间
        self.sku_id = ""  # sku_id
        self.skin_id = 0  # 主题皮肤id
        self.sort_index = 0  # 排序
        self.is_release = 0  # 是否发布：1发布0-未发布
        self.single_lottery_price = 0  # 单抽价格
        self.many_lottery_price = 0  # 连抽价格
        self.many_lottery_num = 0  # 连抽次数
        self.machine_price = 0  # 机台价格
        self.is_repeat_prize = 0  # 是否奖品不重复：0-不重复1-重复
        self.price_gears_id = 0  # 价格档位ID
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'act_id', 'app_id', 'machine_name', 'machine_type', 'goods_id', 'goods_modify_date', 'sku_id', 'skin_id', 'sort_index', 'is_release', 'single_lottery_price', 'many_lottery_price', 'many_lottery_num', 'machine_price', 'is_repeat_prize', 'price_gears_id', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "machine_info_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class BehaviorLogModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(BehaviorLogModel, self).__init__(BehaviorLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class BehaviorLog:

    def __init__(self):
        super(BehaviorLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.orm_id = 0  # 统计映射表id
        self.inc_value = 0  # 增加的值
        self.create_day = 0  # 创建日
        self.create_month = 0  # 创建月
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'orm_id', 'inc_value', 'create_day', 'create_month', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "behavior_log_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PrizeRosterModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PrizeRosterModel, self).__init__(PrizeRoster, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PrizeRoster:

    def __init__(self):
        super(PrizeRoster, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.machine_id = 0  # 机台id
        self.machine_name = ""  # 机台名称
        self.machine_price = 0  # 机台价格
        self.prize_type = 0  # 奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
        self.prize_id = 0  # 奖品标识
        self.prize_name = ""  # 奖品名称
        self.prize_price = 0  # 奖品价值
        self.prize_pic = ""  # 奖品图片
        self.prize_detail = ""  # 奖品详情图
        self.tag_id = 0  # 奖品标签
        self.award_id = ""  # 奖项标识
        self.award_name = ""  # 奖项名称
        self.user_nick = ""  # 用户昵称
        self.avatar = ""  # 用户头像
        self.prize_code = ""  # 中奖码
        self.order_status = 0  # 订单状态（0未发货1已发货2不予发货）
        self.is_sku = 0  # 是否有SKU
        self.prize_order_id = 0  # 奖品订单id
        self.prize_order_no = ""  # 奖品订单号
        self.sku_id = ""  # sku_id
        self.properties_name = ""  # sku属性
        self.goods_id = 0  # 商品id
        self.goods_code = ""  # 商品编码
        self.goods_code_list = ""  # 多个sku商品编码
        self.main_pay_order_no = ""  # 淘宝主订单号
        self.order_no = ""  # 淘宝子订单号
        self.frequency_source = 0  # 次数来源（0-购买，1商家配置）
        self.sku_detail = ""  # sku详情
        self.right_ename = ""  # 发放的权益(奖品)唯一标识
        self.remark = ""  # 备注
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'machine_id', 'machine_name', 'machine_price', 'prize_type', 'prize_id', 'prize_name', 'prize_price', 'prize_pic', 'prize_detail', 'tag_id', 'award_id', 'award_name', 'user_nick', 'avatar', 'prize_code', 'order_status', 'is_sku', 'prize_order_id', 'prize_order_no', 'sku_id', 'properties_name', 'goods_id', 'goods_code', 'goods_code_list', 'main_pay_order_no', 'order_no', 'frequency_source', 'sku_detail', 'right_ename', 'remark', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "prize_roster_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ActPrizeModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ActPrizeModel, self).__init__(ActPrize, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class ActPrize:

    def __init__(self):
        super(ActPrize, self).__init__()
        self.id = 0  # 标识
        self.act_id = 0  # 活动标识
        self.award_id = ""  # 奖项标识
        self.app_id = ""  # 应用唯一标识
        self.owner_open_id = ""  # 商家OpenID
        self.machine_id = 0  # 机台ID
        self.ascription_type = 0  # 奖品归属（0-活动奖品1-任务奖品）
        self.prize_name = ""  # 奖品名称
        self.prize_title = ""  # 奖品子标题
        self.prize_pic = ""  # 奖品图
        self.prize_detail = ""  # 奖品详情图（json）
        self.goods_id = 0  # 商品id
        self.goods_code = ""  # 商品编码
        self.goods_code_list = ""  # 多个sku商品编码
        self.coupon_type = 0  # 优惠券类型(0无1店铺优惠券2商品优惠券)
        self.right_ename = ""  # 发放的权益(奖品)唯一标识
        self.pool_id = ""  # 奖池ID
        self.coupon_start_date = "1900-01-01 00:00:00"  # 优惠券开始时间
        self.coupon_end_date = "1900-01-01 00:00:00"  # 优惠券结束时间
        self.prize_type = 0  # 奖品类型（1实物2店铺商品3优惠券4参与奖5谢谢参与）
        self.prize_price = 0  # 奖品价格
        self.probability = 0  # 奖品权重
        self.chance = 0  # 概率
        self.surplus = 0  # 奖品库存
        self.is_surplus = 0  # 是否显示奖品库存（1显示0-不显示）
        self.is_prize_notice = 0  # 是否显示中奖跑马灯
        self.prize_limit = 0  # 中奖限制
        self.prize_total = 0  # 奖品总数
        self.lottery_type = 0  # 出奖类型（1概率出奖 2强制概率）
        self.force_count = 0  # 每几件出一件
        self.force_start = 0  # 多少件后才能被抽出
        self.tag_name = ""  # 商品标签
        self.tag_id = 0  # 标签ID
        self.hand_out = 0  # 已发出数量
        self.is_sku = 0  # 是否有SKU
        self.sort_index = 0  # 排序号
        self.is_release = 0  # 是否发布（1是0否）
        self.sku_detail = ""  # sku详情
        self.lottery_sum = 0  # 抽奖累计次数
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'act_id', 'award_id', 'app_id', 'owner_open_id', 'machine_id', 'ascription_type', 'prize_name', 'prize_title', 'prize_pic', 'prize_detail', 'goods_id', 'goods_code', 'goods_code_list', 'coupon_type', 'right_ename', 'pool_id', 'coupon_start_date', 'coupon_end_date', 'prize_type', 'prize_price', 'probability', 'chance', 'surplus', 'is_surplus', 'is_prize_notice', 'prize_limit', 'prize_total', 'lottery_type', 'force_count', 'force_start', 'tag_name', 'tag_id', 'hand_out', 'is_sku', 'sort_index', 'is_release', 'sku_detail', 'lottery_sum', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "act_prize_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2021-03-03 14:10:59
:LastEditors: HuangJingCan
:description: 常用帮助类
"""
import random
import hashlib
import datetime


class SevenHelper:
    """
    :description: 常用帮助类
    """
    @classmethod
    def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names):
        """
        :description: 两个字典列表合并
        :param source_dict_list：源字典表
        :param source_key：源表用来关联的字段
        :param merge_dict_list：需要合并的字典表
        :param merge_key：需要合并的字典表用来关联的字段
        :param merge_columns_names：需要合并的字典表中需要展示的字段
        :return: 
        :last_editors: HuangJingCan
        """
        result = []
        for source_dict in source_dict_list:
            info_list = [i for i in merge_dict_list if source_dict[source_key] != "" and i[merge_key] == source_dict[source_key]]
            if info_list:
                list_key = list(merge_columns_names.split(","))
                source_dict = dict(source_dict, **dict.fromkeys(list_key))
                for item in list_key:
                    source_dict[item] = info_list[0].get(item)
            else:
                list1 = list(merge_columns_names.split(","))
                source_dict = dict(source_dict, **dict.fromkeys(list1))
            result.append(source_dict)
        return result

    @classmethod
    def auto_mapper(self, s_model, map_dict=None):
        '''
        :description: 对象映射（把map_dict值赋值到实体s_model中）
        :param s_model：需要映射的实体对象
        :param map_dict：被映射的实体字典
        :return: obj
        :last_editors: HuangJingCan
        '''
        if map_dict:
            field_list = s_model.get_field_list()
            for filed in field_list:
                if filed in map_dict:
                    setattr(s_model, filed, map_dict[filed])
        return s_model

    @classmethod
    def get_condition_by_id_list(self, primary_key, id_list=None):
        '''
        :description: 根据id_list返回查询条件
        :param primary_key：主键
        :param id_list：id：列表
        :return: str
        :last_editors: HuangJingCan
        '''
        if not id_list:
            return ""
        id_list_str = str(id_list).strip('[').strip(']')
        return f"{primary_key} IN({id_list_str})"

    @classmethod
    def get_random_switch_string(self, random_str, split_chars=","):
        """
        :description: 随机取得字符串
        :param trimChars：根据什么符号进行分割
        :return: str
        :last_editors: HuangJingCan
        """
        if random_str == "":
            return ""
        random_list = [i for i in random_str.split(split_chars) if i != ""]
        return random.choice(random_list)

    @classmethod
    def to_file_size(self, size):
        """
        :description: 文件大小格式化
        :param size：文件大小
        :return: str
        :last_editors: HuangJingCan
        """
        if size < 1000:
            return '%i' % size + 'size'
        elif 1024 <= size < 1048576:
            return '%.2f' % float(size / 1024) + 'KB'
        elif 1048576 <= size < 1073741824:
            return '%.2f' % float(size / 1048576) + 'MB'
        elif 1073741824 <= size < 1000000000000:
            return '%.2f' % float(size / 1073741824) + 'GB'
        elif 1000000000000 <= size:
            return '%.2f' % float(size / 1000000000000) + 'TB'

    @classmethod
    def get_random(self, num, many):
        """
        :description: 获取随机数
        :param num：位数
        :param many：个数
        :return: str
        :last_editors: CaiYouBin
        """
        result = ""
        for x in range(many):
            s = ""
            for i in range(num):
                # n=1 生成数字  n=2 生成字母
                n = random.randint(1, 2)
                if n == 1:
                    numb = random.randint(0, 9)
                    s += str(numb)
                else:
                    nn = random.randint(1, 2)
                    cc = random.randint(1, 26)
                    if nn == 1:
                        numb = chr(64 + cc)
                        s += numb
                    else:
                        numb = chr(96 + cc)
                        s += numb
            result += s
        return result

    @classmethod
    def get_now_day_int(self, hours=0):
        """
        :description: 获取整形的天20200506
        :param hours: 需要增加的小时数
        :return: int（20200506）
        :last_editors: HuangJingCan
        """
        now_date = (datetime.datetime.now() + datetime.timedelta(hours=hours))
        now_day = int(now_date.strftime("%Y%m%d"))
        return now_day

    @classmethod
    def get_now_month_int(self, hours=0):
        """
        :description: 获取整形的月202005
        :param hours: 需要增加的小时数
        :return: int（202005）
        :last_editors: HuangJingCan
        """
        now_date = (datetime.datetime.now() + datetime.timedelta(hours=hours))
        now_month = int(now_date.strftime("%Y%m"))
        return now_month

    @classmethod
    def get_page_count(self, page_size, record_count):
        """
        @description: 计算页数
        @param page_size：页大小
        @param record_count：总记录数
        @return: 页数
        @last_editors: HuangJingCan
        """
        page_count = record_count / page_size + 1
        if page_size == 0:
            page_count = 0
        if record_count % page_size == 0:
            page_count = record_count / page_size
        page_count = int(page_count)
        return page_count


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-05-26 17:38:03
:LastEditTime: 2021-04-16 11:04:07
:LastEditors: HuangJingCan
:description: 主题皮肤相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.theme.theme_info_model import *
from seven_cloudapp.models.db_models.theme.theme_ver_model import *
from seven_cloudapp.models.db_models.skin.skin_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *


class ThemeInfoHandler(SevenBaseHandler):
    """
    :description: 获取主题（皮肤）信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取主题（皮肤）信息
        :param act_id：活动id
        :param ver_no：客户端版本号
        :return 主题信息
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        ver_no = self.get_param("ver_no")
        act_info_model = ActInfoModel(context=self)
        theme_info_model = ThemeInfoModel(context=self)

        act_dict = act_info_model.get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，找不到该活动")

        theme_id = act_dict["theme_id"]
        theme_info = theme_info_model.get_dict("id=%s", params=theme_id)
        if not theme_info:
            return self.reponse_json_error("NoTheme", "对不起，找不到该主题")

        out_id = theme_info["out_id"]
        if ver_no:
            theme_ver = ThemeVerModel(context=self).get_entity("out_id=%s and ver_no=%s", params=[out_id, ver_no])
            if theme_ver and theme_ver.client_json != "":
                theme_info["client_json"] = theme_ver.client_json

        skin_info_list = SkinInfoModel(context=self).get_dict_list("theme_id=%s", params=theme_id)

        theme_info["skin_list"] = skin_info_list

        return self.reponse_json_success(theme_info)


class ThemeSaveHandler(SevenBaseHandler):
    """
    :description: 保存主题
    """
    @filter_check_params("out_id")
    def post_async(self):
        """
        :description: 保存主题
        :param app_id：app_id
        :param theme_name：主题名称
        :param client_json：客户端内容json
        :param server_json：服务端内容json
        :param out_id：外部id
        :param ver_no：客户端版本号
        :return: 
        :last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        theme_name = self.get_param("theme_name")
        client_json = self.get_param("client_json")
        server_json = self.get_param("server_json")
        out_id = self.get_param("out_id")
        ver_no = self.get_param("ver_no")

        theme_info_model = ThemeInfoModel(context=self)
        theme_ver_model = ThemeVerModel(context=self)
        theme_info = theme_info_model.get_entity("out_id=%s", params=out_id)
        if theme_info:
            if client_json:
                if ver_no:
                    theme_ver = theme_ver_model.get_entity('out_id=%s and ver_no=%s', params=[out_id, ver_no])
                    if theme_ver:
                        theme_ver_model.update_table('client_json=%s', 'out_id=%s and ver_no=%s', params=[client_json, out_id, ver_no])
                    else:
                        theme_ver = ThemeVer()
                        theme_ver.app_id = theme_info.app_id
                        theme_ver.out_id = out_id
                        theme_ver.theme_id = theme_info.id
                        theme_ver.client_json = client_json
                        theme_ver.ver_no = ver_no
                        theme_ver.create_date = theme_info.create_date
                        theme_ver_model.add_entity(theme_ver)
                else:
                    theme_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, out_id])
            if server_json:
                theme_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, out_id])
        else:
            theme_total = theme_info_model.get_total()
            if not theme_name:
                return self.reponse_json_error("NoThemeName", "对不起，请输入主题名称")
            theme_info = ThemeInfo()
            theme_info.theme_name = theme_name
            theme_info.client_json = client_json
            theme_info.server_json = server_json
            theme_info.out_id = out_id
            if app_id != "":
                theme_info.app_id = app_id
                theme_info.is_private = 1
            theme_info.sort_index = int(theme_total) + 1
            theme_info.is_release = 1
            theme_info.create_date = self.get_now_datetime()
            theme_id = theme_info_model.add_entity(theme_info)
            if ver_no:
                theme_ver = ThemeVer()
                theme_ver.app_id = theme_info.app_id
                theme_ver.out_id = out_id
                theme_ver.theme_id = theme_id
                theme_ver.client_json = client_json
                theme_ver.ver_no = ver_no
                theme_ver.create_date = theme_info.create_date
                theme_ver_model.add_entity(theme_ver)

        return self.reponse_json_success()


class SkinSaveHandler(SevenBaseHandler):
    """
    :description: 保存皮肤
    """
    @filter_check_params("theme_out_id,skin_out_id")
    def post_async(self):
        """
        :description: 保存皮肤
        :param app_id：app_id
        :param skin_name：皮肤名称
        :param client_json：客户端内容json
        :param server_json：服务端内容json
        :param theme_out_id：样式外部id
        :param skin_out_id：皮肤外部id
        :return: 
        :last_editors: CaiYouBin
        """
        app_id = self.get_param("app_id")
        skin_name = self.get_param("skin_name")
        client_json = self.get_param("client_json")
        server_json = self.get_param("server_json")
        theme_out_id = self.get_param("theme_out_id")
        skin_out_id = self.get_param("skin_out_id")

        skin_info_model = SkinInfoModel(context=self)
        skin_info = skin_info_model.get_entity("out_id=%s", params=skin_out_id)
        if skin_info:
            if client_json:
                skin_info_model.update_table('client_json=%s', 'out_id=%s', params=[client_json, skin_out_id])
            if server_json:
                skin_info_model.update_table('server_json=%s', 'out_id=%s', params=[server_json, skin_out_id])
        else:
            skin_info_total = skin_info_model.get_total('theme_out_id=%s', params=theme_out_id)
            if not skin_name:
                return self.reponse_json_error("NoSkinName", "对不起，请输入皮肤名称")
            skin_info = SkinInfo()
            theme_info_model = ThemeInfoModel(context=self)
            theme_info = theme_info_model.get_entity("out_id=%s", params=theme_out_id)
            if not theme_info:
                return self.reponse_json_error("NoTheme", "没有找到对应主题")

            skin_info.skin_name = skin_name
            skin_info.client_json = client_json
            skin_info.server_json = server_json
            if app_id != "":
                skin_info.app_id = app_id
            skin_info.sort_index = skin_info_total + 1
            skin_info.theme_id = theme_info.id
            skin_info.create_date = self.get_now_datetime()
            skin_info.modify_date = self.get_now_datetime()
            skin_info.out_id = skin_out_id
            skin_info.theme_out_id = theme_out_id
            skin_id = skin_info_model.add_entity(skin_info)

        return self.reponse_json_success()



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class RoleUserModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(RoleUserModel, self).__init__(RoleUser, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class RoleUser:

    def __init__(self):
        super(RoleUser, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.role_id = 0  # 角色标识
        self.is_power = 0  # 是否授权
        self.service_date_start = "1900-01-01 00:00:00"  # 服务开始时间
        self.service_date_end = "1900-01-01 00:00:00"  # 服务结束时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'role_id', 'is_power', 'service_date_start', 'service_date_end', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "role_user_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-05-26 17:51:04
:LastEditTime: 2021-04-15 10:38:54
:LastEditors: HuangJingCan
:description: 抽奖
"""
from seven_cloudapp.handlers.seven_base import *



# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-06-22 17:27:07
:LastEditTime: 2021-04-16 11:07:01
:LastEditors: HuangJingCan
:description: 
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.db_models.ip.ip_series_model import *


class SeriesListHandler(SevenBaseHandler):
    """
    :description: IP系列列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取IP系列列表
        :param act_id:活动id
        :param page_index:页索引
        :param page_size:页大小
        :return: PageInfo
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))

        if act_id <= 0:
            return self.reponse_json_error_params()

        condition = "act_id=%s AND is_release=1"
        params = [act_id]
        order_by = "sort_index desc"

        page_list, total = IpSeriesModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-11-05 10:03:55
:LastEditTime: 2021-04-16 11:08:05
:LastEditors: HuangJingCan
:description: 机台相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.db_models.machine.machine_info_model import *


class MachinieListHandler(SevenBaseHandler):
    """
    :description: 机台列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取机台列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return: 分页列表信息
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))

        condition = "act_id=%s AND app_id=%s AND is_release=1"
        params = [act_id, app_id]
        order_by = "sort_index desc"

        page_list, total = MachineInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-03-24 14:47:27
:LastEditTime: 2021-04-15 08:47:28
:LastEditors: HuangJingCan
@Description: 
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.exchange.exchange_info_model import *


class ExchangeListHandler(SevenBaseHandler):
    """
    :description: 兑换列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 兑换列表
        :param act_id:活动id
        :return: 
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))

        condition = "act_id=%s"
        exchange_info_model = ExchangeInfoModel(context=self)
        exchange_info_list = exchange_info_model.get_dict_list(condition, order_by="id asc", field="id,goods_type,goods_name,need_value,is_release", params=[act_id])

        return self.reponse_json_success(exchange_info_list)


class ExchangeSaveHandler(SevenBaseHandler):
    """
    :description: 保存兑换
    """
    @filter_check_params("act_id,exchange_list")
    def post_async(self):
        """
        :description: 保存兑换
        :param act_id:活动id
        :return: 
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        app_id = self.get_param("app_id")

        exchange_info_model = ExchangeInfoModel(context=self)
        exchange_list = self.get_param("exchange_list")
        exchange_list = self.json_loads(exchange_list)
        exchange_info = ExchangeInfo()
        if len(exchange_list) > 0:
            for item in exchange_list:
                if item.__contains__("id"):
                    exchange_info = exchange_info_model.get_entity_by_id(int(item["id"]))
                exchange_info.goods_type = item["goods_type"]
                exchange_info.goods_name = item["goods_name"]
                exchange_info.need_value = item["need_value"]
                exchange_info.is_release = item["is_release"]
                if exchange_info.id > 0:
                    exchange_info.modify_date = self.get_now_datetime()
                    exchange_info_model.update_entity(exchange_info)
                else:
                    exchange_info.app_id = app_id
                    exchange_info.act_id = act_id
                    exchange_info.create_date = self.get_now_datetime()
                    exchange_info_model.add_entity(exchange_info)

        return self.reponse_json_success()



# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-28 18:03:59
:LastEditTime: 2021-01-05 11:12:41
:LastEditors: HuangJingCan
:description: 主题皮肤
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.theme.theme_info_model import *
from seven_cloudapp.models.db_models.skin.skin_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.machine.machine_info_model import *


class ThemeListHandler(SevenBaseHandler):
    """
    :description: 主题列表
    """
    def get_async(self):
        """
        :description: 主题列表
        :param 
        :return: 列表
        :last_editors: HuangJingCan
        """
        dict_list = ThemeInfoModel(context=self).get_dict_list("is_release=1")

        for dict_info in dict_list:
            dict_info["client_json"] = self.json_loads(dict_info["client_json"]) if dict_info["client_json"] else {}
            dict_info["server_json"] = self.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}

        self.reponse_json_success(dict_list)


class SkinListHandler(SevenBaseHandler):
    """
    :description: 皮肤列表
    """
    @filter_check_params("theme_id")
    def get_async(self):
        """
        :description: 皮肤列表
        :param theme_id：主题id
        :return: 列表
        :last_editors: HuangJingCan
        """
        theme_id = int(self.get_param("theme_id", 0))

        if theme_id <= 0:
            return self.reponse_json_error_params()

        dict_list = SkinInfoModel(context=self).get_dict_list("theme_id=%s", params=theme_id)

        for dict_info in dict_list:
            dict_info["client_json"] = self.json_loads(dict_info["client_json"]) if dict_info["client_json"] else {}
            dict_info["server_json"] = self.json_loads(dict_info["server_json"]) if dict_info["server_json"] else {}

        self.reponse_json_success(dict_list)


class ThemeUpdate(SevenBaseHandler):
    """
    :description: 小程序主题更新
    """
    @filter_check_params("act_id,theme_id")
    def get_async(self):
        """
        :description: 小程序主题更新
        :param act_id：活动id
        :param theme_id：主题id
        :return: 
        :last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        act_id = self.get_param("act_id")
        theme_id = int(self.get_param("theme_id", 0))
        is_machine = int(self.get_param("is_machine", 1))

        act_info_model = ActInfoModel(context=self)
        act_info = act_info_model.get_entity("id=%s", params=act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，找不到该活动")
        if act_info.theme_id == theme_id:
            return self.reponse_json_error("NoAct", "对不起，主题未改变")

        skin_info = SkinInfoModel(context=self).get_entity("theme_id=%s", params=theme_id)
        if not skin_info:
            return self.reponse_json_error("NoAct", "对不起，主题没有皮肤")

        act_info_model.update_table("theme_id=%s", "id=%s", [theme_id, act_id])

        if is_machine == 1:
            MachineInfoModel(context=self).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])

        self.reponse_json_success()



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ExchangeInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ExchangeInfoModel, self).__init__(ExchangeInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class ExchangeInfo:

    def __init__(self):
        super(ExchangeInfo, self).__init__()
        self.id = 0  # 标识
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.goods_type = 0  # 商品类型(1实物2透视卡3提示卡4重抽卡5优惠券)
        self.need_value = 0  # 所需T币数量
        self.goods_img = ""  # 商品图片
        self.goods_name = ""  # 商品名称
        self.goods_price = 0  # 商品价值
        self.goods_code = ""  # 商品编码
        self.day_limit = 0  # 每日上限
        self.stock_num = 0  # 库存数量
        self.draw_num = 0  # 领取数量
        self.sort_index = 0  # 排序
        self.is_release = 0  # 是否发布：0否1是
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'goods_type', 'need_value', 'goods_img', 'goods_name', 'goods_price', 'goods_code', 'day_limit', 'stock_num', 'draw_num', 'sort_index', 'is_release', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "exchange_info_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: LaiKaiXiang
:Date: 2020-11-16 13:44:20
:LastEditTime: 2021-06-07 16:58:04
:LastEditors: HuangJingCan
:description: 
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.behavior.behavior_log_model import *
from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
from seven_cloudapp.models.db_models.behavior.behavior_report_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *


class ReportTotalHandler(SevenBaseHandler):
    """
    :description: 各类总数统计
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 各类总数统计
        :param act_id：活动id
        :return dict
        :last_editors: LaiKaiXiang
        """
        act_id = int(self.get_param("act_id", 0))

        behavior_report_model = BehaviorReportModel(context=self)

        sum_visit = behavior_report_model.get_dict("act_id=%s and key_name=%s", field="sum(key_value) as key_value", params=[act_id, "VisitManCountEveryDayIncrease"])
        sum_lottery = behavior_report_model.get_dict("act_id=%s and key_name=%s", field="sum(key_value) as key_value", params=[act_id, "LotteryAddUserCount"])
        # sum_win = behavior_report_model.get_dict("act_id=%s and key_name=%s", field="sum(key_value) as key_value", params=[act_id, "WinLotteryAddUserCount"])
        sum_reward = behavior_report_model.get_dict("act_id=%s and key_name=%s", field="sum(key_value) as key_value", params=[act_id, "TotalRewardCount"])

        data_list = []
        data = {}
        data["title"] = "总访问人数"
        data["value"] = int(sum_visit["key_value"]) if sum_visit["key_value"] else 0
        data_list.append(data)
        data = {}
        data["title"] = "总抽奖人数"
        data["value"] = int(sum_lottery["key_value"]) if sum_lottery["key_value"] else 0
        data_list.append(data)
        data = {}
        data["title"] = "奖励发放总量"
        data["value"] = int(sum_reward["key_value"]) if sum_reward["key_value"] else 0
        data_list.append(data)

        return self.reponse_json_success(data_list)


class ReportInfoHandler(SevenBaseHandler):
    """
    :description: 关键数据获取(表格)
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 关键数据获取(表格)
        :param act_id：活动id
        :return list
        :last_editors: LaiKaiXiang
        """
        act_id = int(self.get_param("act_id", 0))
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_success([])

        act_type = act_dict['act_type']

        condition = "act_id=%s"
        params = [act_id]

        if start_date != "":
            condition += " and create_date>=%s"
            params.append(start_date)
        if end_date != "":
            condition += " and create_date<=%s"
            params.append(TimeHelper.add_days_by_format_time(end_date, 1))

        behavior_orm_model = BehaviorOrmModel(context=self)
        behavior_report_model = BehaviorReportModel(context=self)

        # behavior_orm_list = behavior_orm_model.get_list("(is_common=1 and act_type=%s) or act_id=%s", order_by="sort_index asc", params=[act_type, act_id])
        behavior_orm_list = behavior_orm_model.get_list("((is_common=1 and act_type=%s) or act_id=%s) and is_release=1", order_by="sort_index asc", params=[act_type, act_id])
        behavior_report_list = behavior_report_model.get_dict_list(condition, group_by="key_name", field="key_name,SUM(key_value) AS key_value", params=params)

        #公共映射组（未去重）
        common_groups_1 = [orm.group_name for orm in behavior_orm_list if orm.is_common == 1]
        #公共映射组(去重)
        common_groups = list(set(common_groups_1))
        common_groups.sort(key=common_groups_1.index)

        common_group_data_list = []

        for common_group in common_groups:
            group_data = {}
            group_data["group_name"] = common_group
            data_list = []

            # 无子节点
            orm_list = [orm for orm in behavior_orm_list if orm.group_name == common_group and orm.group_sub_name == '']
            for orm in orm_list:
                data = {}
                data["title"] = orm.key_value
                data["value"] = 0
                for behavior_report in behavior_report_list:
                    if behavior_report["key_name"] == orm.key_name:
                        if orm.value_type == 2:
                            data["value"] = behavior_report["key_value"]
                        else:
                            data["value"] = int(behavior_report["key_value"])
                data_list.append(data)
            if len(data_list) > 0:
                group_data["data_list"] = data_list

            # 有子节点
            orm_list_sub = [orm for orm in behavior_orm_list if orm.group_name == common_group and orm.group_sub_name != '']
            if orm_list_sub:
                groups_sub_name = [orm.group_sub_name for orm in orm_list_sub]
                #公共映射组(去重)
                sub_names = list(set(groups_sub_name))
                sub_names.sort(key=groups_sub_name.index)
                sub_group_data_list = []
                for sub_name in sub_names:
                    sub_group_data = {}
                    sub_group_data["group_name"] = sub_name
                    sub_data_list = []

                    # 无子节点
                    orm_list_1 = [orm for orm in behavior_orm_list if orm.group_sub_name == sub_name]
                    for orm in orm_list_1:
                        data = {}
                        data["title"] = orm.key_value
                        data["value"] = 0
                        for behavior_report in behavior_report_list:
                            if behavior_report["key_name"] == orm.key_name:
                                if orm.value_type == 2:
                                    data["value"] = behavior_report["key_value"]
                                else:
                                    data["value"] = int(behavior_report["key_value"])
                        sub_data_list.append(data)
                    sub_group_data["data_list"] = sub_data_list
                    sub_group_data_list.append(sub_group_data)
                group_data["sub_data_list"] = sub_group_data_list

            common_group_data_list.append(group_data)

        return self.reponse_json_success(common_group_data_list)


class ReportInfoListHandler(SevenBaseHandler):
    """
    :description: 关键数据获取(趋势图)
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 关键数据获取(趋势图)
        :param act_id:活动id
        :param start_date:开始时间
        :param end_date:结束时间
        :return list
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_success([])

        act_type = act_dict['act_type']

        date_list = self.get_date_list(start_date, end_date)

        condition = "act_id=%s"
        params = [act_id]

        if start_date != "":
            condition += " and create_date>=%s"
            params.append(start_date)
        if end_date != "":
            condition += " and create_date<=%s"
            params.append(TimeHelper.add_days_by_format_time(end_date, 1))

        behavior_orm_model = BehaviorOrmModel(context=self)
        behavior_report_model = BehaviorReportModel(context=self)

        # behavior_orm_list = behavior_orm_model.get_list("(is_common=1 and act_type=%s) or act_id=%s", order_by="sort_index asc", params=[act_type, act_id])
        behavior_orm_list = behavior_orm_model.get_list("((is_common=1 and act_type=%s) or act_id=%s) and is_release=1", order_by="sort_index asc", params=[act_type, act_id])
        behavior_report_list = behavior_report_model.get_dict_list(condition, field="key_name,key_value,DATE_FORMAT(create_date,'%%Y-%%m-%%d') AS create_date", params=params)

        #公共映射组（未去重）
        common_groups_1 = [orm.group_name for orm in behavior_orm_list if orm.is_common == 1]
        #公共映射组(去重)
        common_groups = list(set(common_groups_1))
        common_groups.sort(key=common_groups_1.index)

        common_group_data_list = []

        for common_group in common_groups:
            group_data = {}
            group_data["group_name"] = common_group
            data_list = []

            # 无子节点
            orm_list = [orm for orm in behavior_orm_list if orm.group_name == common_group and orm.group_sub_name == '']
            for orm in orm_list:
                data = {}
                data["title"] = orm.key_value
                data["value"] = []
                for date_day in date_list:
                    behavior_date_report = {}
                    for behavior_report in behavior_report_list:
                        if behavior_report["key_name"] == orm.key_name and behavior_report["create_date"] == date_day:
                            if orm.value_type != 2:
                                behavior_report["key_value"] = int(behavior_report["key_value"])
                            behavior_date_report = {"title": orm.key_value, "date": date_day, "value": behavior_report["key_value"]}
                            break
                    if not behavior_date_report:
                        behavior_date_report = {"title": orm.key_value, "date": date_day, "value": 0}
                    data["value"].append(behavior_date_report)
                data_list.append(data)
            if len(data_list) > 0:
                group_data["data_list"] = data_list

            # 有子节点
            orm_list_sub = [orm for orm in behavior_orm_list if orm.group_name == common_group and orm.group_sub_name != '']
            if orm_list_sub:
                groups_sub_name = [orm.group_sub_name for orm in orm_list_sub]
                #公共映射组(去重)
                sub_names = list(set(groups_sub_name))
                sub_names.sort(key=groups_sub_name.index)
                sub_group_data_list = []
                for sub_name in sub_names:
                    sub_group_data = {}
                    sub_group_data["group_name"] = sub_name
                    sub_data_list = []

                    # 无子节点
                    orm_list_1 = [orm for orm in behavior_orm_list if orm.group_sub_name == sub_name]
                    for orm in orm_list_1:
                        data = {}
                        data["title"] = orm.key_value
                        data["value"] = []
                        for date_day in date_list:
                            behavior_date_report = {}
                            for behavior_report in behavior_report_list:
                                if behavior_report["key_name"] == orm.key_name and behavior_report["create_date"] == date_day:
                                    if orm.value_type != 2:
                                        behavior_report["key_value"] = int(behavior_report["key_value"])
                                    behavior_date_report = {"title": orm.key_value, "date": date_day, "value": behavior_report["key_value"]}
                                    break
                            if not behavior_date_report:
                                behavior_date_report = {"title": orm.key_value, "date": date_day, "value": 0}
                            data["value"].append(behavior_date_report)
                        sub_data_list.append(data)
                    sub_group_data["data_list"] = sub_data_list
                    sub_group_data_list.append(sub_group_data)
                group_data["sub_data_list"] = sub_group_data_list

            common_group_data_list.append(group_data)

        return self.reponse_json_success(common_group_data_list)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-19 11:33:16
:LastEditTime: 2021-04-16 14:24:45
:LastEditors: HuangJingCan
:description: 用户处理
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.behavior_model import *
from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.task.task_info_model import *
from seven_cloudapp.models.db_models.task.task_count_model import *
from seven_cloudapp.models.db_models.lottery.lottery_value_log_model import *
from seven_cloudapp.models.db_models.user.user_blacklist_model import *


class TaskBaseHandler(TopBaseHandler):
    """
    :description: 任务基础类
    """
    def check_common(self, act_dict, user_info, task_info, act_id, open_id, login_token, check_task=True):
        """
        :description: 做任务前的资格校验
        :param act_dict:活动信息
        :param user_info:用户信息
        :param task_info:任务信息
        :param act_id:活动ID
        :param open_id:open_id
        :param login_token:访问令牌
        :param check_task:任务校验
        :return:
        :last_editors: HuangJianYi
        """
        invoke_result = {}
        invoke_result['code'] = "0"
        invoke_result['message'] = "成功"
        task_type = "0"
        if check_task:
            if not task_info:
                invoke_result['code'] = "NoTask"
                invoke_result['message'] = "对不起，任务不存在"
                return invoke_result
            if task_info.is_release == 0:
                invoke_result['code'] = "NoRelease"
                invoke_result['message'] = "对不起,未配置任务"
                return invoke_result
            task_type = str(task_info.task_type)

        #请求太频繁限制
        if self.check_post(f"Task_Post_{str(act_id)}_{str(task_type)}_{str(open_id)}") == False:
            invoke_result['code'] = "HintMessage"
            invoke_result['message'] = "对不起，请稍后再试"
            return invoke_result

        if not act_dict:
            invoke_result['code'] = "NoAct"
            invoke_result['message'] = "对不起，活动不存在"
            return invoke_result

        now_date = self.get_now_datetime()
        if act_dict['start_date'] != "":
            if TimeHelper.format_time_to_datetime(now_date) < act_dict['start_date']:
                invoke_result['code'] = "NoAct"
                invoke_result['message'] = "活动将在" + act_dict['start_date'] + "开启"
                return invoke_result
        if act_dict['end_date'] != "":
            if TimeHelper.format_time_to_datetime(now_date) > act_dict['end_date']:
                invoke_result['code'] = "NoAct"
                invoke_result['message'] = "活动已结束"
                return invoke_result
        if not user_info:
            invoke_result['code'] = "NoUser"
            invoke_result['message'] = "对不起，用户不存在"
            return invoke_result
        if user_info.user_nick == "":
            invoke_result['code'] = "NoUserNick"
            invoke_result['message'] = "对不起，请先授权"
            return invoke_result
        if user_info.user_state == 1:
            invoke_result['code'] = "UserState"
            invoke_result['message'] = "对不起，你是黑名单用户,无法操作"
            return invoke_result
        if login_token != "":
            if user_info.login_token != login_token:
                invoke_result['code'] = "ErrorToken"
                invoke_result['message'] = "对不起，已在另一台设备登录,无法操作"
                return invoke_result

        return invoke_result

    def check_black(self, user_info, act_dict, all_goods_order_list):
        """
        :description: 判断是否满足拉黑条件
        :param user_info:用户信息
        :param act_dict:活动信息
        :param all_goods_order_list:下单商品相关订单列表
        :return:
        :last_editors: HuangJianYi
        """
        user_info_model = UserInfoModel(context=self)
        result = False
        if user_info.user_state == 0 and act_dict['is_black'] == 1 and act_dict['refund_count'] > 0:
            #退款的订单  子订单存在退款 记录一次
            refund_order_data = [i for i in all_goods_order_list if i["refund_status"] not in self.refund_status()]
            #如果不是黑用户 并且存在退款时间 代表黑用户解禁
            if user_info.relieve_date != '1900-01-01 00:00:00':
                refund_order_data = [i for i in refund_order_data if TimeHelper.format_time_to_datetime(i['pay_time']) > TimeHelper.format_time_to_datetime(user_info.relieve_date)]
            #超过变成黑用户
            if len(refund_order_data) >= act_dict['refund_count']:
                result = True
                user_info_model.update_table("user_state=1", "id=%s", user_info.id)
                user_blacklist_model = UserBlacklistModel(context=self)
                user_blacklist = user_blacklist_model.get_entity("act_id=%s and open_id=%s", params=[user_info.act_id, user_info.open_id])
                if user_blacklist:
                    user_blacklist.black_type = 1
                    user_blacklist.reason = ""
                    user_blacklist.audit_status = 0
                    user_blacklist.audit_remark = ""
                    user_blacklist.refund_count += len(refund_order_data)
                    all_refund_order_data = self.json_loads(user_blacklist.refund_order_data)
                    if len(refund_order_data) > 0:
                        for item in refund_order_data:
                            all_refund_order_data.append(item)
                    user_blacklist.refund_order_data = self.json_dumps(all_refund_order_data)
                    user_blacklist_model.update_entity(user_blacklist)
                else:
                    user_blacklist = UserBlacklist()
                    user_blacklist.app_id = user_info.app_id
                    user_blacklist.act_id = user_info.act_id
                    user_blacklist.open_id = user_info.open_id
                    user_blacklist.user_nick = user_info.user_nick
                    user_blacklist.black_type = 1
                    user_blacklist.reason = ""
                    user_blacklist.audit_status = 0
                    user_blacklist.audit_remark = ""
                    user_blacklist.refund_count = len(refund_order_data)
                    user_blacklist.refund_order_data = self.json_dumps(refund_order_data)
                    user_blacklist.create_date = self.get_now_datetime()
                    user_blacklist_model.add_entity(user_blacklist)
        return result

    def send_lottery_value(self, log_title, user_info, update_sql, send_num, act_dict, source_type, change_type, currency_type, log_info="", log_desc="", main_pay_order_no=""):
        """
        :description: 任务完成发送奖励
        :param log_title:标题
        :param user_info:用户信息
        :param update_sql:用户更新语句
        :param send_num:奖励数量
        :param act_dict:活动信息
        :param source_type:来源类型：1-购买2-任务3-手动配置4抽奖
        :param change_type:变动类型
        :param currency_type:货币类型（0无1次数2积分3价格档位）
        :param log_desc:备注
        :param log_info:日志
        :return:
        :last_editors: HuangJianYi
        """
        lottery_value_log = LotteryValueLog()
        lottery_value_log.app_id = user_info.app_id
        lottery_value_log.act_id = user_info.act_id
        lottery_value_log.open_id = user_info.open_id
        lottery_value_log.user_nick = user_info.user_nick
        lottery_value_log.log_title = log_title
        lottery_value_log.log_desc = log_desc
        lottery_value_log.log_info = log_info if log_info != "" else {}
        lottery_value_log.currency_type = currency_type
        lottery_value_log.source_type = source_type  #任务
        lottery_value_log.change_type = change_type
        lottery_value_log.operate_type = 0
        lottery_value_log.current_value = send_num
        lottery_value_log.history_value = (user_info.lottery_value if currency_type == 1 else user_info.surplus_integral) - send_num
        lottery_value_log.create_date = self.get_now_datetime()
        lottery_value_log.main_pay_order_no = main_pay_order_no

        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
        lottery_value_log_model = LotteryValueLogModel(db_transaction=db_transaction, context=self)
        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self)
        result = False

        try:
            db_transaction.begin_transaction()
            lottery_value_log_model.add_entity(lottery_value_log)
            if update_sql != "":
                user_info_model.update_table(update_sql, "id=%s", params=user_info.id)
            db_transaction.commit_transaction()
            result = True
        except Exception as ex:
            self.logging_link_error(traceback.format_exc())
            db_transaction.rollback_transaction()

        if result:
            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(user_info.app_id, user_info.act_id, user_info.open_id, "", 'JoinUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(user_info.app_id, user_info.act_id, user_info.open_id, "", 'TotalRewardCount', send_num, act_dict['act_type'])
            behavior_model.report_behavior_log(user_info.app_id, user_info.act_id, user_info.open_id, "", 'AddJoinUserCount', 1, act_dict['act_type'])

        return result

    def get_task_currency_type(self, task_currency_type, task_type):
        """
        :description: 获取任务货币类型
        :param task_currency_type:任务货币类型配置  key:1次数2积分4抽奖码100其他（混合搭配）
        :param task_type:任务类型（整形）
        :return 任务货币类型
        :last_editors: HuangJingCan
        """
        currency_type = 0
        if task_currency_type == "":
            return currency_type
        task_currency_type_dict = self.json_loads(task_currency_type)
        if not task_currency_type_dict:
            return currency_type
        if int(task_currency_type_dict["key"]) != 100:
            currency_type = int(task_currency_type_dict["key"])
            return currency_type
        value_dict = task_currency_type_dict["value"]
        if not value_dict:
            return currency_type
        if str(task_type) in value_dict.keys():
            currency_type = value_dict[str(task_type)]
        return currency_type


# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-06-22 10:30:00
:LastEditTime: 2021-04-22 17:36:28
:LastEditors: HuangJingCan
:description: ip系列
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.enum import *
from seven_cloudapp.models.db_models.ip.ip_series_model import *


class SeriesHandler(SevenBaseHandler):
    """
    :description: 保存IP系列
    """
    @filter_check_params("app_id,act_id,series_name,series_pic")
    def get_async(self):
        """
        :description: 保存IP系列
        :param series_id 系列id
        :return: reponse_json_success
        :last_editors: HuangJianYi
        """
        # app_id = "3000000003444475"
        # ip_series = IpSeries()
        # ip_series.act_id=1
        # ip_series.app_id=2
        # ip_series.series_name = "海贼王"
        # self.create_operation_log(OperationType.add.value, ip_series.__str__(), "SeriesHandler", None, self.json_dumps(ip_series.__dict__))
        app_id = self.get_param("app_id")
        open_id = self.get_taobao_param().open_id
        series_id = int(self.get_param("series_id", 0))
        act_id = int(self.get_param("act_id", 0))
        series_name = self.get_param("series_name")
        series_pic = self.get_param("series_pic")
        show_pic = self.get_param("show_pic")
        sort_index = int(self.get_param("sort_index", 0))
        is_release = int(self.get_param("is_release", 1))

        if act_id <= 0:
            return self.reponse_json_error_params()

        ip_series = None
        ip_series_model = IpSeriesModel(context=self)
        if series_id > 0:
            ip_series = ip_series_model.get_entity_by_id(series_id)

        is_add = False
        if not ip_series:
            is_add = True
            ip_series = IpSeries()

        old_ip_series = ip_series
        ip_series.act_id = act_id
        ip_series.app_id = app_id
        ip_series.series_name = series_name
        ip_series.series_pic = series_pic
        ip_series.show_pic = show_pic
        ip_series.sort_index = sort_index
        ip_series.is_release = is_release
        ip_series.modify_date = self.get_now_datetime()

        if is_add:
            ip_series.create_date = ip_series.modify_date
            ip_series.id = ip_series_model.add_entity(ip_series)
            # 记录日志
            self.create_operation_log(OperationType.add.value, ip_series.__str__(), "SeriesHandler", None, self.json_dumps(ip_series))
        else:
            ip_series_model.update_entity(ip_series)
            # 记录日志
            self.create_operation_log(OperationType.update.value, ip_series.__str__(), "SeriesHandler", self.json_dumps(old_ip_series), self.json_dumps(ip_series))

        self.reponse_json_success(ip_series.id)


class SeriesListHandler(SevenBaseHandler):
    """
    :description: IP系列信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取IP系列列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return: list
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))

        if act_id <= 0:
            return self.reponse_json_error_params()

        condition = "act_id=%s"
        params = [act_id]
        order_by = "sort_index desc"

        page_list, total = IpSeriesModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        self.reponse_json_success(page_info)


class SeriesDelHandler(SevenBaseHandler):
    """
    :description: 删除系列
    """
    @filter_check_params("series_id")
    def get_async(self):
        """
        :description: 删除系列
        :param series_id：系列id
        :return: reponse_json_success
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        series_id = int(self.get_param("series_id", 0))

        if series_id <= 0:
            return self.reponse_json_error_params()

        IpSeriesModel(context=self).del_entity("id=%s", series_id)

        self.create_operation_log(OperationType.delete.value, "ip_series_tb", "SeriesDelHandler", None, series_id)

        self.reponse_json_success()


class SeriesReleaseHandler(SevenBaseHandler):
    """
    :description: 系列上下架
    """
    @filter_check_params("series_id,is_release")
    def get_async(self):
        """
        :description: 系列上下架
        :param series_id：系列id
        :param is_release：是否发布（0下架1上架）
        :return: reponse_json_success
        :last_editors: HuangJianYi
        """
        series_id = int(self.get_param("series_id", 0))
        is_release = int(self.get_param("is_release", 0))

        if series_id <= 0:
            return self.reponse_json_error_params()

        IpSeriesModel(context=self).update_table("is_release=%s", "id=%s", [is_release, series_id])

        self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-12 20:11:48
:LastEditTime: 2021-05-26 10:47:56
:LastEditors: HuangJingCan
:description: SevenBaseHandler
"""
import ast
import random
import decimal
from copy import deepcopy
from asq.initiators import query

from seven_framework.redis import *
from seven_framework.web_tornado.base_handler.base_api_handler import *

from seven_cloudapp.libs.customize.seven_helper import *

from seven_cloudapp.models.taobao_model import *
from seven_cloudapp.models.db_models.operation.operation_log_model import *
from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.middler.middler_product_model import *
from seven_cloudapp.models.db_models.role.role_power_model import *
from seven_cloudapp.models.db_models.role.role_user_model import *


class SevenBaseHandler(BaseApiHandler):
    """
    :description: SevenBaseHandler
    """
    def prepare(self):
        """
        :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
        :last_editors: HuangJingCan
        """
        if self.__class__.__name__ == "IndexHandler":
            return

        dict_par = {}
        dict_par["open_id"] = self.get_taobao_param().open_id
        dict_par["nick_name"] = self.get_taobao_param().user_nick
        dict_par["app_id"] = self.get_param("app_id")
        if not dict_par["app_id"]:
            dict_par["app_id"] = self.get_taobao_param().source_app_id

        # 标记日志请求关联
        self._build_http_log(dict_par)

    def options_async(self):
        self.reponse_json_success()

    def check_xsrf_cookie(self):
        return

    def json_dumps(self, rep_dic):
        """
        :description: 将字典转化为字符串
        :param rep_dic：字典对象
        :return: str
        :last_editors: HuangJingCan
        """
        if isinstance(rep_dic, str):
            rep_dic = ast.literal_eval(rep_dic)
        if hasattr(rep_dic, '__dict__'):
            rep_dic = rep_dic.__dict__
        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, default=lambda x: (x.__dict__ if not isinstance(x, datetime.datetime) else datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S')) if not isinstance(x, decimal.Decimal) else float(x), sort_keys=False, indent=2)

    def json_loads(self, rep_str):
        """
        :description: 将字符串转化为字典
        :param rep_str：str
        :return: dict
        :last_editors: HuangJingCan
        """
        try:
            return json.loads(rep_str)
        except Exception as ex:
            return json.loads(self.json_dumps(rep_str))

    def reponse_custom(self, rep_dic):
        """
        :description: 输出公共json模型
        :param rep_dic: 字典类型数据
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.http_reponse(self.json_dumps(rep_dic))

    def reponse_common(self, success=True, data=None, error_code="", error_message=""):
        """
        :description: 输出公共json模型
        :param success: 布尔值，表示本次调用是否成功
        :param data: 类型不限，调用成功（success为true）时，服务端返回的数据
        :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
        :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        if hasattr(data, '__dict__'):
            data = data.__dict__
        template_value = {}
        template_value['success'] = success
        template_value['data'] = data
        template_value['error_code'] = error_code
        template_value['error_message'] = error_message

        rep_dic = {}
        rep_dic['success'] = True
        rep_dic['data'] = template_value

        log_extra_dict = {}
        log_extra_dict["is_success"] = 1
        if success == False:
            log_extra_dict["is_success"] = 0

        self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)

    def reponse_json_success(self, data=None):
        """
        :description: 通用成功返回json结构
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.reponse_common(data=data)

    def reponse_json_error(self, error_code="", error_message="", data=None, log_type=0):
        """
        :description: 通用错误返回json结构
        :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
        :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
        :param data: 返回结果对象，即为数组，字典
        :param log_type: 日志记录类型（0-不记录，1-info，2-error）
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        if log_type == 1:
            self.logging_link_info(f"{error_code}\n{error_message}\n{data}\n{self.request}")
        elif log_type == 2:
            self.logging_link_error(f"{error_code}\n{error_message}\n{data}\n{self.request}")
        self.reponse_common(False, data, error_code, error_message)

    def reponse_json_error_params(self):
        """
        :description: 通用参数错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: ChenXiaolei
        """
        self.reponse_common(False, None, "params error", "参数错误")

    def return_dict_error(self, error_code="", error_message=""):
        """
        :description: 返回error信息字典模型
        :param errorCode: 字符串，服务端返回的错误码
        :param errorMessage: 字符串，服务端返回的错误信息
        :return: dict
        :last_editors: HuangJingCan
        """
        rep_dic = {}
        rep_dic['error_code'] = error_code
        rep_dic['error_message'] = error_message

        self.logging_link_error(f"{error_code}\n{error_message}\n{self.request}")

        return rep_dic

    def redis_init(self, db=None):
        """
        :description: redis初始化
        :return: redis_cli
        :last_editors: HuangJingCan
        """
        host = config.get_value("redis")["host"]
        port = config.get_value("redis")["port"]
        if not db:
            db = config.get_value("redis")["db"]
        password = config.get_value("redis")["password"]
        redis_cli = RedisHelper.redis_init(host, port, db, password)
        return redis_cli

    def get_taobao_param(self):
        """
        :description: 获取淘宝上下文参数
        :return: TaoBaoParam
        :last_editors: HuangJingCan
        """
        app_key = self.get_param("app_key")
        user_nick = self.get_param("user_nick")
        open_id = self.get_param("open_id")
        env = self.get_param("env")
        mini_app_id = self.get_param("mini_app_id")
        access_token = self.get_param("access_token")
        sign = self.get_param("sign")
        mix_nick = self.get_param("mix_nick")
        user_id = self.get_param("user_id")
        main_user_id = self.get_param("main_user_id")
        source_app_id = self.get_param("source_app_id")
        request_id = self.get_param("request_id")

        #region 指定测试账号和小程序,用于在IDE上测试(前端通过source_app_id关联数据,后端通过user_nick关联数据)
        if source_app_id == config.get_value("client_template_id"):
            #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
            source_app_id = config.get_value("test_source_app_id")
        if source_app_id == "":
            #后端（在IDE上返回空，在千牛上返回后端模板ids）
            source_app_id = config.get_value("test_source_app_id")
            user_nick = config.get_value("test_user_nick")
            open_id = config.get_value("test_open_id")
        #endregion

        info = TaoBaoParam()
        info.app_key = app_key
        info.user_nick = user_nick
        info.open_id = open_id
        info.env = env
        info.mini_app_id = mini_app_id
        info.access_token = access_token
        info.sign = sign
        info.mix_nick = mix_nick
        info.user_id = user_id
        info.main_user_id = main_user_id
        info.source_app_id = source_app_id
        info.request_id = request_id

        return info

    def get_app_id(self):
        """
        :description: 获取app_id
        :param self
        :return str
        :last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        if app_id == "":
            user_nick = self.get_taobao_param().user_nick
            if user_nick:
                store_user_nick = user_nick.split(':')[0]
                if store_user_nick:
                    dict_app_id = AppInfoModel(context=self).get_dict("store_user_nick=%s", field="app_id", params=store_user_nick)
                    if dict_app_id:
                        app_id = dict_app_id["app_id"]
        return app_id

    def create_order_id(self, ran=5):
        """
        :description: 生成订单号
        :param ran：随机数位数，默认5位随机数（0-5）
        :return: 25位的订单号
        :last_editors: HuangJingCan
        """
        ran_num = ""
        if ran == 1:
            ran_num = random.randint(0, 9)
        elif ran == 2:
            ran_num = random.randint(10, 99)
        elif ran == 3:
            ran_num = random.randint(100, 999)
        elif ran == 4:
            ran_num = random.randint(1000, 9999)
        elif ran == 5:
            ran_num = random.randint(10000, 99999)
        # cur_time = TimeHelper.get_now_format_time('%Y%m%d%H%M%S%f')
        cur_time = TimeHelper.get_now_timestamp(True)
        order_id = str(cur_time) + str(ran_num)
        return order_id

    def get_now_datetime(self):
        """
        :description: 获取当前时间
        :return: str
        :last_editors: HuangJingCan
        """
        add_hours = config.get_value("add_hours", 0)
        return TimeHelper.add_hours_by_format_time(hour=add_hours)

    def create_operation_log(self, operation_type=1, model_name="", handler_name="", detail=None, update_detail=None):
        """
        :description: 创建操作日志
        :param operation_type：操作类型：1-add，2-update，3-delete
        :param model_name：模块或表名称
        :param handler_name：handler名称
        :param detail：当前信息
        :param update_detail：更新之后的信息
        :return: 
        :last_editors: HuangJingCan
        """
        operation_log = OperationLog()
        operation_log_model = OperationLogModel(context=self)

        operation_log.user_nick = self.get_taobao_param().user_nick
        operation_log.app_id = self.get_taobao_param().source_app_id
        operation_log.act_id = int(self.get_param("act_id", 0))
        operation_log.open_id = self.get_taobao_param().open_id
        operation_log.request_params = self.request_params
        operation_log.method = self.request.method
        operation_log.protocol = self.request.protocol
        operation_log.request_host = self.request.host
        operation_log.request_uri = self.request.uri
        operation_log.remote_ip = self.get_remote_ip()
        operation_log.create_date = TimeHelper.get_now_format_time()
        operation_log.operation_type = operation_type
        operation_log.model_name = model_name
        operation_log.handler_name = handler_name
        operation_log.detail = detail
        operation_log.update_detail = update_detail

        if isinstance(operation_log.request_params, dict):
            operation_log.request_params = self.json_dumps(operation_log.request_params)
        if isinstance(detail, dict):
            operation_log.detail = self.json_dumps(detail)
        if isinstance(update_detail, dict):
            operation_log.update_detail = self.json_dumps(update_detail)

        operation_log_model.add_entity(operation_log)

    def get_is_test(self):
        """
        :description: 判断是否本地测试
        :return: bool
        :last_editors: HuangJianYi
        """
        if self.get_taobao_param().env != "online":
            return True
        return False

    def check_post(self, redis_key, expire=1):
        """
         :description: 请求太频繁校验
         :return: bool
         :last_editors: HuangJianYi
         """
        post_value = self.redis_init().get(redis_key)
        if post_value == None:
            self.redis_init().set(redis_key, 10, ex=expire)
            return True
        return False

    def check_lpush(self, queue_name, value, limitNum=100):
        """
         :description: 入队列校验
         :return: bool
         :last_editors: HuangJianYi
         """
        list_len = self.redis_init().llen(queue_name)
        if int(list_len) >= int(limitNum):
            return False
        self.redis_init().lpush(queue_name, json.dumps(value))
        return True

    def lpop(self, queue_name):
        """
         :description: 出队列
         :param queue_name：队列名称
         :return: 
         :last_editors: HuangJianYi
         """
        result = self.redis_init().lpop(queue_name)
        return result

    def acquire_lock(self, lock_name, acquire_time=10, time_out=10):
        """
        :description: 获取一个分布式锁
        :param lock_name：锁定名称
        :param acquire_time: 客户端等待获取锁的时间
        :param time_out: 锁的超时时间
        :return bool
        :last_editors: HuangJianYi
        """
        identifier = str(uuid.uuid4())
        end = time.time() + acquire_time
        lock = "lock:" + lock_name
        while time.time() < end:
            if self.redis_init().setnx(lock, identifier):
                # 给锁设置超时时间, 防止进程崩溃导致其他进程无法获取锁
                self.redis_init().expire(lock, time_out)
                return identifier
            if self.redis_init().ttl(lock) == -1:
                self.redis_init().expire(lock, time_out)
            time.sleep(0.001)
        return False

    def release_lock(self, lock_name, identifier):
        """
        :description: 释放一个锁
        :param lock_name：锁定名称
        :param identifier: identifier
        :return bool
        :last_editors: HuangJianYi
        """
        lock = "lock:" + lock_name
        pip = self.redis_init().pipeline(True)
        while True:
            try:
                pip.watch(lock)
                lock_value = self.redis_init().get(lock)
                if not lock_value:
                    return True
                if lock_value.decode() == identifier:
                    pip.multi()
                    pip.delete(lock)
                    pip.execute()
                    return True
                pip.unwatch()
                break
            except redis.excetions.WacthcError:
                pass
        return False

    def random_weight(self, random_prize_dict_list):
        """
        :description:  根据权重算法获取商品
        :param random_prize_dict_list：权重列表
        :return: str
        :last_editors: HuangJianYi
        """
        total = sum(random_prize_dict_list.values())  # 权重求和
        ra = random.uniform(0, total)  # 在0与权重和之前获取一个随机数
        curr_sum = 0
        ret = None
        keys = random_prize_dict_list.keys()
        for k in keys:
            curr_sum += random_prize_dict_list[k]  # 在遍历中，累加当前权重值
            if ra <= curr_sum:  # 当随机数<=当前权重和时，返回权重key
                ret = k
                break
        return ret

    def get_status_name(self, status_id):
        """
        :description: 获取状态
        :param status_id：状态id
        :return str
        :last_editors: HuangJingCan
        """
        if status_id == 0:
            return "未发货"
        if status_id == 1:
            return "已发货"
        if status_id == 2:
            return "不予发货"
        if status_id == 3:
            return "订单同步失败"

    def get_date_list(self, start_date, end_date):
        """
        :description: 两个日期之间的日期列表
        :param start_date：开始日期
        :param end_date：结束日期
        :return: list
        :last_editors: CaiYouBin
        """
        if not start_date or not end_date:
            return []

        datestart = datetime.datetime.strptime(start_date, '%Y-%m-%d %H:%M:%S')
        dateend = datetime.datetime.strptime(end_date, '%Y-%m-%d %H:%M:%S')

        date_list = []

        while datestart < dateend:
            date_list.append(datestart.strftime('%Y-%m-%d'))
            datestart += datetime.timedelta(days=1)
        return date_list

    def get_online_url(self, act_id, app_id, machine_id=""):
        """
        :description: 获取online_url
        :param act_id:活动id
        :param app_id:app_id
        :param machine_id:机台id
        :param page:跳转的首页地址pages/index/index
        :return str
        :last_editors: HuangJingCan
        """
        page_index = ""
        page = config.get_value("page_index")
        if page:
            page_index = "&page=" + CodingHelper.url_encode(page)
        query = CodingHelper.url_encode(f"actid={act_id}")
        if machine_id:
            query = CodingHelper.url_encode(f"actid={act_id}&machine_id={machine_id}")
        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
        return online_url

    def get_live_url(self, app_id):
        """
        :description: 获取live_url
        :param app_id:app_id
        :return str
        :last_editors: HuangJingCan
        """
        live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
        return live_url

    def get_app_key_secret(self):
        """
        :description: 获取app_key和app_secret
        :param 
        :return app_key, app_secret
        :last_editors: HuangJingCan
        """
        request_app_key = int(self.get_param("app_key", 0))
        app_key = config.get_value("app_key")
        app_secret = config.get_value("app_secret")

        if request_app_key not in (0, app_key):
            dict_product = MiddlerProductModel(context=self).get_dict("app_key=%s", field="app_secret", params=request_app_key)
            if dict_product:
                app_key = request_app_key
                app_secret = dict_product["app_secret"]

        return app_key, app_secret

    def get_currency_type_name(self, currency_type):
        """
        :description: 获取抽奖货币类型名称
        :param currency_type:来源类型：1-购买2-任务3-手动配置4抽奖
        :return str
        :last_editors: HuangJingCan
        """
        currency_type = int(currency_type)
        if currency_type == 1:
            return "抽奖次数"
        if currency_type == 2:
            return "积分"
        if currency_type == 4:
            return "抽奖码"
        return ""

    def get_power_menu(self, app_id):
        """
        :description: 获取权限菜单列表
        :param {*}
        :return {*}
        :last_editors: HuangJingCan
        """
        now_datetime = self.get_now_datetime()
        data = []
        if not app_id:
            return data
        role_user_model = RoleUserModel(context=self)
        role_power_model = RolePowerModel(context=self)
        role_user_dict_list = role_user_model.get_dict_list("app_id=%s and is_power=1 and %s>=service_date_start and %s<=service_date_end", params=[app_id, now_datetime, now_datetime])
        if len(role_user_dict_list) <= 0:
            return self.reponse_json_success(data)
        role_id_list = query(role_user_dict_list).where(lambda x: x["role_id"] > 0).select(lambda x: x["role_id"]).to_list()
        if len(role_id_list) <= 0:
            return self.reponse_json_success(data)
        data = role_power_model.get_dict_list(SevenHelper.get_condition_by_id_list("role_id", role_id_list))
        if len(data) > 0:
            # data = query(data).select(lambda x: {'role_id': x["role_id"], 'menu_id': x["menu_id"]}).to_list()
            data = query(data).select(lambda x: str(x["menu_id"])).to_list()
            data = list(set(data))
        return data

    def lottery_algorithm_chance(self, prize_list):
        """
        :description: 抽奖算法（概率）
        :param prize_list:奖品列表
        :return: 中奖的奖品
        :last_editors: HuangJianYi
        """
        init_value = 0.00
        probability_list = []
        for prize in prize_list:
            current_prize = prize
            current_prize["start_probability"] = init_value
            current_prize["end_probability"] = init_value + float(prize["chance"])
            probability_list.append(current_prize)
            init_value = init_value + float(prize["chance"])
        prize_index = random.uniform(0.00, init_value)
        for prize in probability_list:
            if (prize["start_probability"] <= prize_index and prize_index < prize["end_probability"]):
                return prize

    def lottery_algorithm(self, prize_list):
        """
        :description: 抽奖算法（权重）
        :param prize_list:奖品列表
        :return: 中奖的奖品
        :last_editors: HuangJianYi
        """
        init_value = 0
        probability_list = []
        for prize in prize_list:
            current_prize = prize
            current_prize["start_probability"] = init_value
            current_prize["end_probability"] = init_value + prize["probability"]
            probability_list.append(current_prize)
            init_value = init_value + prize["probability"]
        prize_index = random.randint(0, init_value - 1)
        for prize in probability_list:
            if (prize["start_probability"] <= prize_index and prize_index < prize["end_probability"]):
                return prize


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-05-26 15:26:32
:LastEditTime: 2021-02-26 13:37:10
:LastEditors: HuangJingCan
:description: 客户端活动处理
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *


class ActInfoHandler(SevenBaseHandler):
    """
    :description: 获取活动信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取活动信息
        :param act_id：活动id
        :return: 字典
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        app_id = self.get_taobao_param().source_app_id

        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，找不到该小程序")

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，找不到该活动")

        act_dict["seller_id"] = app_info.seller_id
        act_dict["store_id"] = app_info.store_id
        act_dict["store_name"] = app_info.store_name
        act_dict["store_icon"] = app_info.store_icon
        act_dict["app_icon"] = app_info.app_icon

        return self.reponse_json_success(act_dict)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-29 09:40:42
:LastEditTime: 2021-04-16 10:39:28
:LastEditors: HuangJingCan
:description: 机台（盒子）
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.enum import OperationType
from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.behavior_model import *
from seven_cloudapp.models.db_models.machine.machine_info_model import *
from seven_cloudapp.models.db_models.machine.machine_value_model import *
from seven_cloudapp.models.db_models.machine.machine_value_log_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *


class MachineListHandler(SevenBaseHandler):
    """
    :Description: 机台信息
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :Description: 获取机台列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return: list
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))

        if act_id <= 0:
            return self.reponse_json_error_params()

        page_list, total = MachineInfoModel(context=self).get_dict_page_list("*", page_index, page_size, "act_id=%s", "", "sort_index desc", act_id)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class MachineDelHandler(SevenBaseHandler):
    """
    :description: 删除机台
    """
    @filter_check_params("machine_id")
    def get_async(self):
        """
        :description: 删除机台
        :param machine_id：机台id
        :return: reponse_json_success
        :last_editors: HuangJingCan
        """
        machine_id = int(self.get_param("machine_id", 0))

        if machine_id <= 0:
            return self.reponse_json_error_params()

        ActPrizeModel(context=self).del_entity("machine_id=%s", machine_id)

        MachineInfoModel(context=self).del_entity("id=%s", machine_id)

        MachineValueModel(context=self).del_entity("machine_id=%s", machine_id)

        BehaviorOrmModel(context=self).del_entity("key_name='openUserCount_" + str(machine_id) + "' or key_name='openCount_" + str(machine_id) + "'")

        self.create_operation_log(OperationType.delete.value, "machine_info_tb", "MachineDelHandler", None, machine_id)

        return self.reponse_json_success()


class MachineReleaseHandler(SevenBaseHandler):
    """
    :description: 机台上下架
    """
    @filter_check_params("machine_id,is_release")
    def get_async(self):
        """
        :description: 机台上下架
        :param machine_id：机台id
        :param is_release：是否发布（0下架1上架）
        :return: 
        :last_editors: HuangJingCan
        """
        machine_id = int(self.get_param("machine_id", 0))
        is_release = int(self.get_param("is_release", 0))

        if machine_id <= 0:
            return self.reponse_json_error_params()

        MachineInfoModel(context=self).update_table("is_release=%s", "id=%s", [is_release, machine_id])

        return self.reponse_json_success()


class MachineValueLogHandler(SevenBaseHandler):
    """
    :description: 用户机台配置记录
    """
    @filter_check_params("act_id,user_open_id")
    def get_async(self):
        """
        :description: 用户机台配置记录
        :param act_id：活动id
        :param user_open_id：用户唯一标识
        :return 列表
        :last_editors: HuangJingCan
        """
        act_id = self.get_param("act_id")
        user_open_id = self.get_param("user_open_id")

        machine_info_model = MachineInfoModel(context=self)
        machine_value_model = MachineValueModel(context=self)
        machine_value_log_model = MachineValueLogModel(context=self)

        machine_info_list = machine_info_model.get_list("act_id=%s", params=act_id)
        machine_value_log_list_dict = machine_value_log_model.get_dict_list("act_id=%s and open_id=%s", order_by='id desc', params=[act_id, user_open_id])
        machine_value_list = machine_value_model.get_list("act_id=%s and open_id=%s", params=[act_id, user_open_id])

        machine_value_log_groups = []
        for machine_info in machine_info_list:
            machine_value_log_group = {}
            machine_value_log_group["machine_id"] = machine_info.id
            machine_value_log_group["machine_name"] = machine_info.machine_name
            for machine_value in machine_value_list:
                if machine_value.machine_id == machine_info.id:
                    machine_value_log_group["surplus_value"] = machine_value.surplus_value
                    machine_value_log_group["open_value"] = machine_value.open_value
                    continue
            if "surplus_value" not in machine_value_log_group.keys():
                machine_value_log_group["surplus_value"] = 0
            if "open_value" not in machine_value_log_group.keys():
                machine_value_log_group["open_value"] = 0
            machine_value_log_group["machine_value_log_list"] = [i for i in machine_value_log_list_dict if i["machine_id"] == machine_info.id]
            machine_value_log_groups.append(machine_value_log_group)

        return self.reponse_json_success(machine_value_log_groups)


class CheckBuyEndboxHandler(SevenBaseHandler):
    """
    :description: 判断是否满足开启端盒的条件
    """
    @filter_check_params("machine_id")
    def get_async(self):
        """
        :description: 判断是否满足开启端盒的条件
        :param machine_id：机台id
        :return: 1满足0不满足
        :last_editors: HuangJianYi
        """
        machine_id = int(self.get_param("machine_id", 0))
        specs_type = int(self.get_param("specs_type", 0))

        act_prize_model = ActPrizeModel(context=self)
        prize_lottery_count = act_prize_model.get_total("machine_id=%s and tag_id=1", params=machine_id)

        if prize_lottery_count >= specs_type:
            return self.reponse_json_success(True)

        return self.reponse_json_success(False)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-26 14:45:44
:LastEditTime: 2021-03-17 11:04:57
:LastEditors: HuangJingCan
:description: 通用Handler
"""
from seven_cloudapp.handlers.seven_base import *


class IndexHandler(SevenBaseHandler):
    """
    :description: 默认页
    """
    def get_async(self):
        """
        :description: 默认页
        :param 
        :return 字符串
        :last_editors: HuangJingCan
        """
        self.write(UUIDHelper.get_uuid() + "_" + config.get_value("run_port") + "_api")



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class BaseInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(BaseInfoModel, self).__init__(BaseInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class BaseInfo:

    def __init__(self):
        super(BaseInfo, self).__init__()
        self.id = 0  # id
        self.guid = ""  # guid
        self.product_name = ""  # 产品名称
        self.product_icon = ""  # 产品图标
        self.product_desc = ""  # 产品简介
        self.service_market_url = ""  # 服务市场链接
        self.customer_service = ""  # 客服号
        self.experience_img = ""  # 案例二维码图
        self.client_ver = ""  # 客户端版本号
        self.server_ver = ""  # 服务端版本号
        self.update_function = ""  # 版本更新内容
        self.update_function_b = ""  # 千牛端版本更新内容
        self.store_study_url = ""  # 店铺装修教程图文地址（如何上架小程序）
        self.study_url = ""  # 后台配置图文教程
        self.video_url = ""  # 后台配置视频教程
        self.course_url = ""  # 主账号授权子账号教程
        self.price_gare = ""  # 价格档位说明
        self.product_price = ""  # 产品价格信息
        self.decoration_poster = ""  # 装修海报
        self.friend_link = ""  # 友情链接
        self.course_strategy = ""  # 教程或者攻略
        self.menu_config = ""  # 菜单配置信息
        self.is_remind_phone = 0  # 是否提醒提示配置手机号
        self.is_force_update = 0  # 是个强制更新客户端版本
        self.is_contact_us = 0  # 是否提醒联系我们
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'guid', 'product_name', 'product_icon', 'product_desc', 'service_market_url', 'customer_service', 'experience_img', 'client_ver', 'server_ver', 'update_function', 'update_function_b', 'store_study_url', 'study_url', 'video_url', 'course_url', 'price_gare', 'product_price', 'decoration_poster', 'friend_link', 'course_strategy', 'menu_config', 'is_remind_phone', 'is_force_update', 'is_contact_us', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "base_info_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-19 09:40:27
:LastEditTime: 2020-08-12 10:06:14
:LastEditors: HuangJingCan
:description: 淘宝系统参数
"""


class TaoBaoParam():
    """
    :description: 淘宝参数实体
    :last_editors: HuangJingCan
    """
    def __init__(self):
        # 商家应用的appKey
        self.app_key = ""
        # 当前登录用户的昵称(需要用户授权)
        self.user_nick = ""
        # 当前登录用户的openId
        self.open_id = ""
        # 当前云应用调用环境，入参为：test或者online，对应在云开发中绑定的云容器的测试环境和正式环境。在发布上线的前注意调整env为online，调用正式环境。
        self.env = ""
        # 运行时使用的小程序ID，
        # 1,如果是BC模式，那么这里是B端小程序ID;
        # 2,如果是模板开发模式，这里是模板小程序ID;
        # 3,如果是插件开发模式，这里是宿主小程序的小程序ID;
        self.mini_app_id = ""
        # 当前登录用户的授权token，也是sessionkey（需要用户授权）
        self.access_token = ""
        # 使用当前小程序appkey和secret进行对参数进行加签后的签名
        self.sign = ""
        # 当前登录用户的混淆nick
        self.mix_nick = ""
        # 当前登录用户的userId，仅对老应用迁移生效
        self.user_id = ""
        # 主账号userId，千牛子账号登录授权后可与获取，仅对老应用迁移生效
        self.main_user_id = ""
        # 当前调用小程序的小程序ID
        # 1,如果是BC模式，那么这里是C端小程序ID;
        # 2,如果是模板开发模式，这里是实例化小程序ID;
        # 3,如果是插件开发模式，这里是插件的小程序ID;
        self.source_app_id = ""
        # request_id
        self.request_id = ""


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-06-05 17:10:27
:LastEditTime: 2021-04-14 14:52:03
:LastEditors: HuangJingCan
:description: 统计相关
"""
import decimal

from seven_cloudapp.models.db_models.behavior.behavior_log_model import *
from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
from seven_cloudapp.models.db_models.behavior.behavior_report_model import *


class BehaviorModel():
    """
    :description: 统计相关
    """
    def __init__(self, context=None):
        self.context = context

    def report_behavior(self, app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type=0):
        """
        :description: 上报行为记录（弃用）
        :param app_id：app_id
        :param act_id：活动id
        :param open_id：open_id
        :param owner_open_id：owner_open_id
        :param behavior_key：统计key
        :param behavior_value：统计值
        :return: 
        :last_editors: CaiYouBin
        """
        add_hours = config.get_value("add_hours", 0)
        create_date = TimeHelper.add_hours_by_format_time(hour=add_hours)
        create_date = TimeHelper.format_time_to_datetime(create_date)
        now_month_int = int(TimeHelper.datetime_to_format_time(create_date, "%Y%m"))
        now_day_int = int(TimeHelper.datetime_to_format_time(create_date, "%Y%m%d"))

        behavior_orm_model = BehaviorOrmModel(context=self.context)
        behavior_log_model = BehaviorLogModel(context=self.context)
        behavior_report_model = BehaviorReportModel(context=self.context)
        orm = None
        behavior_log = None
        if act_type > 0:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s and act_type=%s", params=[act_id, behavior_key, act_type])
        else:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s", params=[act_id, behavior_key])
        if not orm:
            return "NotOrm"
        if orm.is_repeat == 1:
            if orm.repeat_type == 2:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s", params=[orm.id, act_id, open_id])
            else:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s and to_days(create_date)=to_days(now())", params=[orm.id, act_id, open_id])
            if not behavior_log:
                behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and to_days(create_date) = to_days(now())", params=[act_id, app_id, behavior_key])
                if not behavior_report:
                    behavior_report = BehaviorReport()
                    behavior_report.app_id = app_id
                    behavior_report.act_id = act_id
                    # behavior_report.owner_open_id
                    behavior_report.key_name = behavior_key
                    behavior_report.key_value = behavior_value
                    behavior_report.create_date = create_date
                    behavior_report.create_year = create_date.year
                    behavior_report.create_month = create_date.month
                    behavior_report.create_day = create_date.day
                    behavior_report_model.add_entity(behavior_report)
                else:
                    behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + decimal.Decimal(behavior_value)
                    behavior_report_model.update_entity(behavior_report)
        else:
            behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and to_days(create_date)=to_days(now())", params=[act_id, app_id, behavior_key])
            if not behavior_report:
                behavior_report = BehaviorReport()
                behavior_report.app_id = app_id
                behavior_report.act_id = act_id
                # behavior_report.owner_open_id
                behavior_report.key_name = behavior_key
                behavior_report.key_value = behavior_value
                behavior_report.create_date = create_date
                behavior_report.create_year = create_date.year
                behavior_report.create_month = create_date.month
                behavior_report.create_day = create_date.day
                behavior_report_model.add_entity(behavior_report)
            else:
                behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + behavior_value
                behavior_report_model.update_entity(behavior_report)

        new_behavior_log = BehaviorLog()
        new_behavior_log.app_id = app_id
        new_behavior_log.act_id = act_id
        new_behavior_log.open_id = open_id
        new_behavior_log.orm_id = orm.id
        new_behavior_log.inc_value = behavior_value
        new_behavior_log.create_day = now_day_int
        new_behavior_log.create_month = now_month_int
        new_behavior_log.create_date = create_date

        behavior_log_model.add_entity(new_behavior_log)

    def report_behavior_log(self, app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type=0):
        """
        :description: 新统计上报,数据库表(behavior_report_tb)加唯一索引（app_id,act_id,key_name,create_day)）,避免重复数据
        :param app_id：app_id
        :param act_id：活动id
        :param open_id：open_id
        :param owner_open_id：owner_open_id
        :param behavior_key：统计key
        :param behavior_value：统计值
        :return: 
        :last_editors: CaiYouBin
        """
        try:
            self.process_behavior(app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type)
        except Exception as ex:
            if str(ex).__contains__("Duplicate entry"):
                self.process_behavior(app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type)

    def process_behavior(self, app_id, act_id, open_id, owner_open_id, behavior_key, behavior_value, act_type=0):
        """
        :description: 上报行为记录
        :param app_id：app_id
        :param act_id：活动id
        :param open_id：open_id
        :param owner_open_id：owner_open_id
        :param behavior_key：统计key
        :param behavior_value：统计值
        :return: 
        :last_editors: HuangJianYi
        """
        add_hours = config.get_value("add_hours", 0)
        create_date = TimeHelper.add_hours_by_format_time(hour=add_hours)
        create_date = TimeHelper.format_time_to_datetime(create_date)
        now_month_int = int(TimeHelper.datetime_to_format_time(create_date, "%Y%m"))
        now_day_int = int(TimeHelper.datetime_to_format_time(create_date, "%Y%m%d"))

        behavior_orm_model = BehaviorOrmModel(context=self.context)
        behavior_log_model = BehaviorLogModel(context=self.context)
        behavior_report_model = BehaviorReportModel(context=self.context)
        orm = None
        behavior_log = None
        if act_type > 0:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s and act_type=%s", params=[act_id, behavior_key, act_type])
        else:
            orm = behavior_orm_model.get_entity("((act_id=%s and is_common=0) or is_common=1) and key_name=%s", params=[act_id, behavior_key])
        if not orm:
            return "NotOrm"
        if orm.is_repeat == 1:
            if orm.repeat_type == 2:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s", params=[orm.id, act_id, open_id])
            else:
                behavior_log = behavior_log_model.get_entity("orm_id=%s and act_id=%s and open_id=%s and create_day=%s", params=[orm.id, act_id, open_id, now_day_int])
            if not behavior_log:
                behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and create_day=%s", params=[act_id, app_id, behavior_key, now_day_int])
                if not behavior_report:
                    behavior_report = BehaviorReport()
                    behavior_report.app_id = app_id
                    behavior_report.act_id = act_id
                    # behavior_report.owner_open_id
                    behavior_report.key_name = behavior_key
                    behavior_report.key_value = behavior_value
                    behavior_report.create_date = create_date
                    behavior_report.create_year = create_date.year
                    behavior_report.create_month = now_month_int
                    behavior_report.create_day = now_day_int
                    behavior_report_model.add_entity(behavior_report)

                else:
                    behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + behavior_value
                    behavior_report_model.update_entity(behavior_report)
        else:
            behavior_report = behavior_report_model.get_entity("act_id=%s and app_id=%s and key_name=%s and create_day=%s", params=[act_id, app_id, behavior_key, now_day_int])
            if not behavior_report:
                behavior_report = BehaviorReport()
                behavior_report.app_id = app_id
                behavior_report.act_id = act_id
                # behavior_report.owner_open_id
                behavior_report.key_name = behavior_key
                behavior_report.key_value = behavior_value
                behavior_report.create_date = create_date
                behavior_report.create_year = create_date.year
                behavior_report.create_month = now_month_int
                behavior_report.create_day = now_day_int
                behavior_report_model.add_entity(behavior_report)
            else:
                behavior_report.key_value = decimal.Decimal(behavior_report.key_value) + decimal.Decimal(behavior_value)
                behavior_report_model.update_entity(behavior_report)

        new_behavior_log = BehaviorLog()
        new_behavior_log.app_id = app_id
        new_behavior_log.act_id = act_id
        new_behavior_log.open_id = open_id
        new_behavior_log.orm_id = orm.id
        new_behavior_log.inc_value = behavior_value
        new_behavior_log.create_day = now_day_int
        new_behavior_log.create_month = now_month_int
        new_behavior_log.create_date = create_date

        behavior_log_model.add_entity(new_behavior_log)

    def save_orm(self, orm_infos, act_id):
        """
        :description: 保存Orm
        :param orm_infos：orm_infos
        :param act_id：活动id
        :return: 
        :last_editors: CaiYouBin
        """
        delete_orm_ids = []
        behavior_orm_model = BehaviorOrmModel(context=self.context)
        behavior_orm_list = behavior_orm_model.get_list('act_id=%s', params=act_id)
        for behavior_orm_item in behavior_orm_list:
            if behavior_orm_item.key_name.find(orm_infos[0].key_name) != -1:
                delete_orm_ids.append(str(behavior_orm_item.id))
            if behavior_orm_item.key_name.find(orm_infos[1].key_name) != -1:
                delete_orm_ids.append(str(behavior_orm_item.id))
        if len(delete_orm_ids) > 0:
            behavior_orm_model.del_entity('id in (' + ','.join(delete_orm_ids) + ')')

        behavior_orm_model.add_list(orm_infos)



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class InviteLogModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(InviteLogModel, self).__init__(InviteLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class InviteLog:

    def __init__(self):
        super(InviteLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.open_id = ""  # 邀请人OpenID
        self.invite_user_nick = ""  # 受邀人昵称
        self.invite_open_id = ""  # 受邀人OpenID
        self.invite_avatar = ""  # 受邀人头像
        self.is_handle = 0  # 是否处理（1处理0未处理）
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.create_day = 0  # 创建天

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'invite_user_nick', 'invite_open_id', 'invite_avatar', 'is_handle', 'create_date', 'create_day']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "invite_log_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PayOrderModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PayOrderModel, self).__init__(PayOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PayOrder:

    def __init__(self):
        super(PayOrder, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.owner_open_id = ""  # 商家OpenID
        self.user_nick = ""  # 用户昵称
        self.real_name = ""  # 真实姓名
        self.main_order_no = ""  # 淘宝主订单号
        self.order_no = ""  # 淘宝订单号
        self.goods_code = ""  # 商品编码
        self.goods_name = ""  # 商品名称
        self.sku_id = ""  # sku_id
        self.sku_name = ""  # sku_name
        self.buy_num = 0  # 购买数量
        self.pay_price = 0  # 购买金额
        self.telephone = ""  # 联系电话
        self.address = ""  # 发货地址
        self.order_status = ""  # 订单状态
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.pay_date = "1900-01-01 00:00:00"  # 支付时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'owner_open_id', 'user_nick', 'real_name', 'main_order_no', 'order_no', 'goods_code', 'goods_name', 'sku_id', 'sku_name', 'buy_num', 'pay_price', 'telephone', 'address', 'order_status', 'create_date', 'pay_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "pay_order_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: 投放相关
:Date: 2020-06-01 14:07:23
:LastEditTime: 2021-04-16 14:24:22
:LastEditors: HuangJingCan
:description: 投放相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.seven_model import *
from seven_cloudapp.models.throw_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.throw.throw_goods_model import *
from seven_cloudapp.models.db_models.machine.machine_info_model import *


class InitThrowGoodsListHandler(SevenBaseHandler):
    """
    :description: 初始化活动投放
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 初始化活动投放
        :param app_id：app_id
        :param act_id：活动id
        :return {*}
        :last_editors: CaiYouBin
        """
        app_id = self.get_param("app_id")
        act_id = int(self.get_param("act_id", 0))

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        machine_goods_id_list = MachineInfoModel(context=self).get_dict_list("act_id=%s and goods_id!=''", field="goods_id", params=act_id)
        prize_goods_id_list = ActPrizeModel(context=self).get_dict_list("act_id=%s and goods_id!='' and goods_id<>0", field="goods_id", params=act_id)

        goods_id_list = []
        if len(machine_goods_id_list) > 0:
            goods_id_list += [int(goods_id["goods_id"]) for goods_id in machine_goods_id_list]

        if len(prize_goods_id_list) > 0:
            goods_id_list += [int(goods_id["goods_id"]) for goods_id in prize_goods_id_list]

        goods_id_list = list(set(goods_id_list))
        online_url = self.get_online_url(act_id, app_id)
        if len(goods_id_list) == 0:
            result_data = {"url": online_url, "act_name": act_dict['act_name'], "goods_list": []}
            return self.reponse_json_success(result_data)

        result_data = ThrowModel(context=self).init_throw_goods_list(act_id, app_id, act_dict['act_name'], online_url, goods_id_list, self.get_now_datetime())

        return self.reponse_json_success(result_data)


class InitThrowGoodsCallBackHandler(SevenBaseHandler):
    """
    :description: 初始化投放商品回调接口
    """
    def get_async(self):
        """
        :description: 初始化投放商品回调接口
        :param act_id：活动id
        :param close_goods_id：投放失败时关闭投放的商品ID（1，2，3）
        :return 
        :last_editors: CaiYouBin
        """
        act_id = int(self.get_param("act_id", 0))
        close_goods_id = self.get_param("close_goods_id")

        ActInfoModel(context=self).update_table("is_throw=1", "id=%s", params=act_id)

        if close_goods_id != "":
            ThrowGoodsModel(context=self).update_table("is_throw=0", "act_id=%s and goods_id in (" + close_goods_id + ")", params=act_id)

        self.reponse_json_success()


class SaveThrowGoodsStatusHandler(SevenBaseHandler):
    """
    :description: 保存更改投放商品的状态
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 保存更改投放商品的状态
        :param act_id：活动id
        :param update_goods_id：更新商品ID（例：1）
        :return 
        :last_editors: CaiYouBin
        """
        act_id = int(self.get_param("act_id", 0))
        update_goods_id = int(self.get_param("update_goods_id", 0))

        if update_goods_id > 0:
            ThrowGoodsModel(context=self).update_table("is_throw=abs(is_throw-1),is_sync=0,throw_date=%s", "act_id=%s and goods_id=%s", [self.get_now_datetime(), act_id, update_goods_id])

        self.reponse_json_success()


class ThrowGoodsListHandler(TopBaseHandler):
    """
    :description: 投放商品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 投放商品列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return 列表
        :last_editors: CaiYouBin
        """
        act_id = int(self.get_param("act_id", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        throw_goods_model = ThrowGoodsModel(context=self)
        throw_goods_list, total = throw_goods_model.get_dict_page_list("*", page_index, page_size, "act_id=%s", "", "id desc", params=act_id)

        #获取商品信息
        goods_list = []
        if len(throw_goods_list) > 0:
            goods_ids = ",".join([str(throw_goods["goods_id"]) for throw_goods in throw_goods_list])
            resq = self.get_goods_list_for_goodsids(goods_ids, self.get_taobao_param().access_token)

            if "items_seller_list_get_response" in resq.keys():
                if "item" in resq["items_seller_list_get_response"]["items"].keys():
                    goods_list = resq["items_seller_list_get_response"]["items"]["item"]
            else:
                return self.reponse_json_error(resq["error_code"], resq["error_message"])
        else:
            resq = self.get_goods_list_for_goodsids("", self.get_taobao_param().access_token)

            if "items_seller_list_get_response" in resq.keys():
                if "item" in resq["items_seller_list_get_response"]["items"].keys():
                    goods_list = resq["items_seller_list_get_response"]["items"]["item"]
            else:
                return self.reponse_json_error(resq["error_code"], resq["error_message"])

        throw_goods_list = SevenHelper.merge_dict_list(throw_goods_list, "goods_id", goods_list, "num_iid", "pic_url,title")

        page_info = PageInfo(page_index, page_size, total, throw_goods_list)
        result_data = {"is_throw": act_dict['is_throw'], "page_info": page_info.__dict__}

        self.reponse_json_success(result_data)


class AsyncThrowGoodsHandler(TopBaseHandler):
    """
    :description: 同步投放商品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 同步投放商品列表
        :param act_id：活动id
        :return 
        :last_editors: CaiYouBin
        """
        act_id = int(self.get_param("act_id", 0))

        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        url = self.get_online_url(act_dict['id'], act_dict['app_id'])

        throw_goods_model = ThrowGoodsModel(context=self)
        throw_goods_list = throw_goods_model.get_list("act_id=%s and is_sync=0 and is_throw=1", params=act_id)
        no_throw_goods_list = throw_goods_model.get_list("act_id=%s and is_sync=0 and is_throw=0", params=act_id)
        # 同步不投放的商品
        if len(no_throw_goods_list) > 0:

            no_throw_goods_id_list = [str(no_throw_goods.goods_id) for no_throw_goods in no_throw_goods_list]
            no_throw_goods_id_list = list(set(no_throw_goods_id_list))
            no_throw_goods_ids = ",".join(no_throw_goods_id_list)

            update_no_throw_goods_list = []
            # 淘宝top接口
            resp = self.change_throw_goods_list_status(no_throw_goods_ids, url, 'false')
            if "error_message" in resp.keys():
                # return self.reponse_json_error("Error", resp["error_message"]["sub_msg"])
                return self.reponse_json_error("Error", resp["error_message"])

            async_result = resp["miniapp_distribution_items_bind_response"]["model_list"]["distribution_order_bind_target_entity_open_result_dto"][0]["bind_result_list"]["distribution_order_bind_base_dto"]
            for async_result_info in async_result:
                no_throw_goods = [no_throw_goods for no_throw_goods in no_throw_goods_list if str(no_throw_goods.goods_id) == async_result_info["target_entity_id"]]
                if len(no_throw_goods) > 0:
                    if async_result_info["success"] == True:
                        no_throw_goods[0].is_sync = 1
                        no_throw_goods[0].sync_date = self.get_now_datetime()
                    else:
                        no_throw_goods[0].error_message = async_result_info["fail_msg"]
                    update_no_throw_goods_list.append(no_throw_goods[0])

            throw_goods_model.update_list(update_no_throw_goods_list)

            # self.logging_link_info(str(resp))

        # 同步投放的商品
        if len(throw_goods_list) > 0:
            throw_goods_id_list = [str(throw_goods.goods_id) for throw_goods in throw_goods_list]
            throw_goods_id_list = list(set(throw_goods_id_list))
            throw_goods_ids = ",".join(throw_goods_id_list)

            update_throw_goods_list = []
            # 淘宝top接口
            resp = self.change_throw_goods_list_status(throw_goods_ids, url, 'true')
            if "error_message" in resp.keys():
                # return self.reponse_json_error("Error", resp["error_message"]["sub_msg"])
                return self.reponse_json_error("Error", resp["error_message"])

            async_result = resp["miniapp_distribution_items_bind_response"]["model_list"]["distribution_order_bind_target_entity_open_result_dto"][0]["bind_result_list"]["distribution_order_bind_base_dto"]
            for async_result_info in async_result:
                throw_goods = [throw_goods for throw_goods in throw_goods_list if str(throw_goods.goods_id) == async_result_info["target_entity_id"]]
                if len(throw_goods) > 0:
                    if async_result_info["success"] == True:
                        throw_goods[0].is_sync = 1
                        throw_goods[0].sync_date = self.get_now_datetime()
                    else:
                        throw_goods[0].is_throw = 0
                        throw_goods[0].is_sync = 1
                        throw_goods[0].error_message = async_result_info["fail_msg"]
                    update_throw_goods_list.append(throw_goods[0])

            throw_goods_model.update_list(update_throw_goods_list)

            # self.logging_link_info(str(resp))

        self.reponse_json_success()



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PropLogModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PropLogModel, self).__init__(PropLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PropLog:

    def __init__(self):
        super(PropLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.change_type = 0  # 变动类型(1手动配置2兑换3使用)
        self.operate_type = 0  # 操作类型(0累计 1消耗)
        self.prop_type = 0  # 道具类型(2透视卡3提示卡4重抽卡)
        self.machine_name = ""  # 机台名称
        self.specs_type = 0  # 中盒规格(5.6,7.8.9.10.12)
        self.operate_value = 0  # 变动值
        self.history_value = 0  # 历史值
        self.title = ""  # 标题
        self.remark = ""  # 备注
        self.create_date_int = 0  # 创建天
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'user_nick', 'change_type', 'operate_type', 'prop_type', 'machine_name', 'specs_type', 'operate_value', 'history_value', 'title', 'remark', 'create_date_int', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "prop_log_tb"
    